#!/usr/bin/env python3
# Copyright (c) 2004-present Facebook All rights reserved.
# Use of this source code is governed by a BSD-style
# license that can be found in the LICENSE file.


from psym.client import SymphonyClient
from psym.common.data_class import Kpi, ruleLimit

from ..graphql.input.edit_rule_limit_input import EditRuleLimitInput
from ..graphql.input.add_rule_limit_input import AddRuleLimitInput
from ..graphql.mutation.add_rule_limit import addRuleLimit
from ..graphql.mutation.edit_rule_limit import editRuleLimit
from ..graphql.mutation.remove_rule_limit import removeRuleLimit
from psym.common.constant import PAGINATION_STEP
from typing import Any, Dict, Iterator, List, Optional




def add_rule_limit(
    client: SymphonyClient, 
            number: int,
            limitType: str,
            comparator: str,
            rule: str,
) -> ruleLimit:
   
    rule_limit_input = AddRuleLimitInput(            
            number= number,
            limitType=limitType,
            comparator=comparator,
            rule=rule,)
    result = addRuleLimit.execute(client, input=rule_limit_input)
    return ruleLimit(            
            id=result.id,
            number=result.number,
            limitType=result.limitType,
            comparator=result.comparator,
            rule=result.rule,)


def edit_rule_limit(
    client: SymphonyClient,
    rule_limit: ruleLimit,
    new_number: Optional[int] = None,
    limitType: str= None,
    comparator: str= None,
    rule: str= None,
) -> None:
    params: Dict[str, Any] = {}
    if new_number is not None:
        params.update({"_name_": new_number})
    if new_number is not None:
        editRuleLimit.execute(client, input=EditRuleLimitInput(
        id=rule_limit.id, 
        number= new_number,
        limitType=limitType,
        comparator=comparator,
        rule=rule))



def remove_rule_limit(client: SymphonyClient, id: str) -> None:
    removeRuleLimit.execute(client, id=id)





#!/usr/bin/env python3
# Copyright (c) 2004-present Facebook All rights reserved.
# Use of this source code is governed by a BSD-style
# license that can be found in the LICENSE file.


from psym.client import SymphonyClient
from psym.common.data_class import domain

from ..graphql.input.edit_domain_input import EditDomainInput
from ..graphql.input.add_domain_input import AddDomainInput
from ..graphql.mutation.add_domain import addDomain
from ..graphql.mutation.edit_domain import editDomain
from ..graphql.mutation.remove_domain import removeDomain
from ..graphql.query.domain import domains
from psym.common.constant import PAGINATION_STEP
from typing import Any, Dict, Iterator, List, Optional




def add_domain(
    client: SymphonyClient, name: str
) -> domain:
   
    domain_input = AddDomainInput(name=name)
    result = addDomain.execute(client, input=domain_input)
    return domain(name=result.name, id=result.id)

def edit_domain(
    client: SymphonyClient,
    domain: domain,
    new_name: Optional[str] = None,
) -> None:
    params: Dict[str, Any] = {}
    if new_name is not None:
        params.update({"_name_": new_name})
    if new_name is not None:
        editDomain.execute(client, input=EditDomainInput(id=domain.id, name=new_name))

def get_domains(client: SymphonyClient) -> Iterator[domain]:

    domains_ = domains.execute(client, first=PAGINATION_STEP)
    edges = domains_.edges if domains_ else []
    while domains_ is not None and domains_.pageInfo.hasNextPage:
        domains_ = domains.execute(
            client, after=domains_.pageInfo.endCursor, first=PAGINATION_STEP
        )
        if domains_ is not None:
            edges.extend(domains_.edges)

    for edge in edges:
        node = edge.node
        if node is not None:
            yield domain(
                id=node.id,
                name=node.name,
            )


def remove_domain(client: SymphonyClient, id: str) -> None:
    removeDomain.execute(client, id=id)


#!/usr/bin/env python3
# Copyright (c) 2004-present Facebook All rights reserved.
# Use of this source code is governed by a BSD-style
# license that can be found in the LICENSE file.


from psym.client import SymphonyClient
from psym.common.data_class import NetworkType, domain

from ..graphql.input.edit_network_type_input import EditNetworkTypeInput
from ..graphql.input.add_network_type_input import AddNetworkTypeInput
from ..graphql.mutation.add_network_type import addNetworkType
from ..graphql.mutation.edit_network_type import editNetworkType
from ..graphql.mutation.remove_network_type import removeNetworkType
from ..graphql.query.network_types import networkTypes
from psym.common.constant import PAGINATION_STEP
from typing import Any, Dict, Iterator, List, Optional




def add_network_type(
    client: SymphonyClient, name: str
) -> NetworkType:
   
    network_type_input = AddNetworkTypeInput(name=name)
    result = addNetworkType.execute(client, input=network_type_input)
    return NetworkType(name=result.name, id=result.id)

def edit_network_type(
    client: SymphonyClient,
    network_type: NetworkType,
    new_name: Optional[str] = None,
) -> None:
    params: Dict[str, Any] = {}
    if new_name is not None:
        params.update({"_name_": new_name})
    if new_name is not None:
        editNetworkType.execute(client, input=EditNetworkTypeInput(id=network_type.id, name=new_name))


def get_network_types(client: SymphonyClient) -> Iterator[NetworkType]:

    network_types_ = networkTypes.execute(client, first=PAGINATION_STEP)
    edges = network_types_.edges if network_types_ else []
    while network_types_ is not None and network_types_.pageInfo.hasNextPage:
        network_types_ = networkTypes.execute(
            client, after=network_types_.pageInfo.endCursor, first=PAGINATION_STEP
        )
        if network_types_ is not None:
            edges.extend(network_types_.edges)

    for edge in edges:
        node = edge.node
        if node is not None:
            yield NetworkType(
                id=node.id,
                name=node.name,
            )


def remove_network_type(client: SymphonyClient, id: str) -> None:
    removeNetworkType.execute(client, id=id)


#!/usr/bin/env python3
# Copyright (c) 2004-present Facebook All rights reserved.
# Use of this source code is governed by a BSD-style
# license that can be found in the LICENSE file.


from psym.client import SymphonyClient
from psym.common.data_class import Kpi, domain, KpiCategory

from ..graphql.input.edit_kpi_input import EditKpiInput
from ..graphql.input.add_kpi_input import AddKpiInput
from ..graphql.mutation.add_kpi import addKpi
from ..graphql.mutation.edit_kpi import editKpi
from ..graphql.mutation.remove_kpi import removeKpi
from ..graphql.query.kpis import kpis
from psym.common.constant import PAGINATION_STEP
from typing import Any, Dict, Iterator, List, Optional




def add_kpi(
    client: SymphonyClient, name: str, description: str, status: bool, domain: str, kpiCategory: str
) -> Kpi:
   
    domain_input = AddKpiInput(name=name, description=description,
    status=status, 
    domainFk=domain,
    kpiCategoryFK=kpiCategory)

    result = addKpi.execute(client, input=domain_input)

    return Kpi(name=result.name, id=result.id, 
    description=result.description, 
    status=result.status, 
    domain=result.domainFk, 
    kpiCategory=result.kpiCategoryFK)

def edit_kpi(
    client: SymphonyClient,
    KPI: Kpi,
    new_name: Optional[str] = None,
    description: str = None,
    status: bool = None,
    domain: domain = None,
    kpiCategory: KpiCategory = None,
) -> None:
    params: Dict[str, Any] = {}
    if new_name is not None:
        params.update({"_name_": new_name})
    if new_name is not None:
        editKpi.execute(client, input=EditKpiInput(id=KPI.id, 
        name=new_name,
        description=description,
        status= status,
        domainFk=domain,
        kpiCategoryFK=kpiCategory
        ))


def get_kpis(client: SymphonyClient) -> Iterator[Kpi]:

    kpis_ = kpis.execute(client, first=PAGINATION_STEP)
    edges = kpis_.edges if kpis_ else []
    while kpis_ is not None and kpis_.pageInfo.hasNextPage:
        kpis_ = kpis.execute(
            client, after=kpis_.pageInfo.endCursor, first=PAGINATION_STEP
        )
        if kpis_ is not None:
            edges.extend(kpis_.edges)

    for edge in edges:
        node = edge.node
        if node is not None:
            yield Kpi(
                id=node.id,
                name=node.name,
                description=node.description,
                status=node.status,
                domain=node.id,
                kpiCategory=node.id


            )


def remove_kpi(client: SymphonyClient, id: str) -> None:
    removeKpi.execute(client, id=id)










#!/usr/bin/env python3
# Copyright (c) 2004-present Facebook All rights reserved.
# Use of this source code is governed by a BSD-style
# license that can be found in the LICENSE file.


from psym.client import SymphonyClient
from psym.common.data_class import counterFormula, formula, counter

from ..graphql.input.edit_counter_formula_input import EditCounterFormulaInput
from ..graphql.input.add_counter_formula_input import AddCounterFormulaInput
from ..graphql.mutation.add_counter_formula import addCounterFormula
from ..graphql.mutation.edit_counter_formula import editCounterFormula
from ..graphql.mutation.remove_counter_formula import removeCounterFormula
from psym.common.constant import PAGINATION_STEP
from typing import Any, Dict, Iterator, List, Optional




def add_counter_formula(
    client: SymphonyClient,  mandatory: bool, counterFk: str,  formulaFK: str
) -> counterFormula:
   
    domain_input = AddCounterFormulaInput(
    mandatory=mandatory,
    counterFk=counterFk,
    formulaFk=formulaFK)

    result = addCounterFormula.execute(client, input=domain_input)

    return counterFormula(mandatory=result.mandatory,
    id=result.id,  
    counterFk=result.counterFk, 
    formulaFK=result.formulaFk)

def edit_ounter_formula(
    client: SymphonyClient,
    counterFormula: counterFormula,
    new_name: Optional[bool] = None,
    formulaFK: formula = None,
    counterFk: counter = None
) -> None:
    params: Dict[str, Any] = {}
    if new_name is not None:
        params.update({True: new_name})
    if new_name is not None:
        editCounterFormula.execute(client, input=EditCounterFormulaInput(
        id=counterFormula.id, 
        mandatory=new_name,
        counterFk=counterFk,
        formulaFK=formulaFK,
        ))










#!/usr/bin/env python3
# Copyright (c) 2004-present Facebook All rights reserved.
# Use of this source code is governed by a BSD-style
# license that can be found in the LICENSE file.


from psym.client import SymphonyClient
from psym.common.data_class import CounterFamily, Vendor, counter

from ..graphql.input.edit_counter_input import EditCounterInput
from ..graphql.input.add_counter_input import AddCounterInput
from ..graphql.mutation.add_counter import addCounter
from ..graphql.mutation.edit_counter import editCounter
from ..graphql.mutation.remove_counter import removeCounter
from ..graphql.query.counters import counters
from psym.common.constant import PAGINATION_STEP
from typing import Any, Dict, Iterator, List, Optional




def add_counter(
    client: SymphonyClient, name: str, externalID: str, networkManagerSystem: str,  counterFamily: str, vendor: str
) -> counter:
   
    domain_input = AddCounterInput(name=name, 
    externalID=externalID,
    networkManagerSystem=networkManagerSystem, 
    counterFamily=counterFamily,
    vendorFk=vendor)

    result = addCounter.execute(client, input=domain_input)

    return counter(name=result.name, id=result.id, 
    externalID=result.externalID, 
    networkManagerSystem=result.networkManagerSystem, 
    counterFamilyFk=result.counterFamily, 
    vendorFk=result.vendorFk)

def edit_counter(
    client: SymphonyClient,
    counter: counter,
    new_name: Optional[str] = None,
    externalID: str = None,
    networkManagerSystem: str = None,
    vendor: Vendor = None,
) -> None:
    params: Dict[str, Any] = {}
    if new_name is not None:
        params.update({"_name_": new_name})
    if new_name is not None:
        editCounter.execute(client, input=EditCounterInput(
        id=counter.id, 
        name=new_name,
        externalID=externalID,
        networkManagerSystem=networkManagerSystem,
        vendorFk=vendor,
        ))

def get_counters(client: SymphonyClient) -> Iterator[counter]:

    counters_ = counters.execute(client, first=PAGINATION_STEP)
    edges = counters_.edges if counters_ else []
    while counters_ is not None and counters_.pageInfo.hasNextPage:
        counters_ = counters.execute(
            client, after=counters_.pageInfo.endCursor, first=PAGINATION_STEP
        )
        if counters_ is not None:
            edges.extend(counters_.edges)

    for edge in edges:
        node = edge.node
        if node is not None:
            yield counter(
                id=node.id,
                name=node.name,
                externalID=node.externalID,
                networkManagerSystem=node.networkManagerSystem,
                counterFamilyFk=node.counterFamily,
                vendorFk=node.vendorFk
            )


def remove_counter(client: SymphonyClient, id: str) -> None:
    removeCounter.execute(client, id=id)












#!/usr/bin/env python3
# Copyright (c) 2004-present Facebook All rights reserved.
# Use of this source code is governed by a BSD-style
# license that can be found in the LICENSE file.

from numbers import Number
from typing import List, Sequence, cast

from psym.graphql.fragment.equipment import EquipmentFragment
from psym.graphql.fragment.equipment_port_type import EquipmentPortTypeFragment
from psym.graphql.fragment.equipment_type import EquipmentTypeFragment
from psym.graphql.fragment.location import LocationFragment
from psym.graphql.fragment.location_type import LocationTypeFragment
from psym.graphql.fragment.project import ProjectFragment
from psym.graphql.fragment.project_type import ProjectTypeFragment
from psym.graphql.fragment.property_type import PropertyTypeFragment
from psym.graphql.fragment.service_type import ServiceTypeFragment
from psym.graphql.fragment.work_order import WorkOrderFragment
from psym.graphql.fragment.work_order_type import WorkOrderTypeFragment
from psym.graphql.input.property_type_input import PropertyTypeInput

from .data_class import (
    Equipment,
    EquipmentPortType,
    EquipmentType,
    Location,
    LocationType,
    Project,
    ProjectType,
    PropertyDefinition,
    ServiceEndpointDefinition,
    ServiceType,
    WorkOrder,
    WorkOrderDefinition,
    WorkOrderType,
)


def format_to_property_definition(
    property_type_fragment: PropertyTypeFragment,
) -> PropertyDefinition:
    """This function gets `psym.graphql.fragment.property_type.PropertyTypeFragment` object as argument
    and formats it to `psym.common.data_class.PropertyDefinition` object

        :param property_type_fragment: Existing property type fragment object
        :type property_type_fragment: :class:`~psym.graphql.fragment.property_type.PropertyTypeFragment`

        :return: PropertyDefinition object
        :rtype: :class:`~psym.common.data_class.PropertyDefinition`

        **Example**

        .. code-block:: python

            property_definition = format_to_property_definition(
                property_type_fragment=property_type_fragment,
            )
    """
    return PropertyDefinition(
        id=property_type_fragment.id,
        property_name=property_type_fragment.name,
        property_kind=property_type_fragment.type,
        default_raw_value=property_type_fragment.rawValue,
        is_fixed=not property_type_fragment.isInstanceProperty,
        external_id=property_type_fragment.externalId,
        is_mandatory=property_type_fragment.isMandatory,
        is_deleted=property_type_fragment.isDeleted,
    )


def format_to_property_definitions(
    data: Sequence[PropertyTypeFragment],
) -> Sequence[PropertyDefinition]:
    """This function gets Sequence[ `PropertyTypeFragment` ] as argument and formats it to Sequence[ `PropertyDefinition` ]

    :param data: Existing property type fragments sequence
    :type data: Sequence[ :class:`~psym.graphql.fragment.property_type.PropertyTypeFragment` ]

    :return: PropertyDefinitions sequence
    :rtype: Sequence[ :class:`~psym.common.data_class.PropertyDefinition` ]

    **Example**

    .. code-block:: python

        property_definitions = format_to_property_definitions(
            data=property_type_fragments,
        )
    """
    return [
        format_to_property_definition(property_type_fragment)
        for property_type_fragment in data
    ]


def format_to_property_type_input(
    property_definition: PropertyDefinition,
    is_new: bool = True,
    property_type_id=None,
) -> PropertyTypeInput:
    """This function gets `PropertyDefinition` object as argument and formats it to `PropertyTypeInput` object

    :param property_definition: Existing property definition object
    :type property_definition: :class:`~psym.common.data_class.PropertyDefinition`
    :param is_new: Is new flag
    :type is_new: bool

    :return: PropertyTypeInput object
    :rtype: :class:`~psym.graphql.input.property_type.PropertyTypeInput`

    **Example**

    .. code-block:: python

        property_type_input = format_to_property_type_input(
            property_definition=property_definition,
        )
    """
    string_value = None
    int_value = None
    boolean_value = None
    float_value = None
    latitude_value = None
    longitude_value = None
    range_from_value = None
    range_to_value = None

    kind = property_definition.property_kind.value

    if property_definition.default_raw_value is not None:
        default_raw_value = property_definition.default_raw_value
        if kind == "int":
            int_value = int(default_raw_value, base=10)
        elif kind == "bool":
            boolean_value = True if default_raw_value.lower() == "true" else False
        elif kind == "float":
            float_value = cast(Number, float(default_raw_value))
        elif kind == "range":
            string_range = default_raw_value.split(" - ")
            range_from_value = cast(Number, float(string_range[0]))
            range_to_value = cast(Number, float(string_range[1]))
        elif kind == "gps_location":
            string_coordinates = default_raw_value.split(", ")
            latitude_value = cast(Number, float(string_coordinates[0]))
            longitude_value = cast(Number, float(string_coordinates[1]))
        else:
            string_value = default_raw_value

    new_property_type_id = property_definition.id
    if is_new:
        new_property_type_id = None
    elif property_type_id is not None:
        new_property_type_id = property_type_id

    return PropertyTypeInput(
        id=new_property_type_id,
        name=property_definition.property_name,
        type=property_definition.property_kind,
        externalId=property_definition.external_id
        if not is_new and property_definition.external_id
        else None,
        stringValue=string_value,
        intValue=int_value,
        booleanValue=boolean_value,
        floatValue=float_value,
        latitudeValue=latitude_value,
        longitudeValue=longitude_value,
        rangeFromValue=range_from_value,
        rangeToValue=range_to_value,
        isInstanceProperty=not property_definition.is_fixed,
        isMandatory=property_definition.is_mandatory,
        isDeleted=property_definition.is_deleted,
    )


def format_to_property_type_inputs(
    data: Sequence[PropertyDefinition],
) -> List[PropertyTypeInput]:
    """This function gets Sequence[ `PropertyDefinition` ] as argument and formats it to Sequence[ `PropertyTypeInput` ]

    :param data: Existing property definitions sequence
    :type data: Sequence[ :class:`~psym.common.data_class.PropertyDefinition` ]

    :return: PropertyTypeInputs list
    :rtype: List[ :class:`~psym.graphql.input.property_type.PropertyTypeInput` ]

    **Example**

    .. code-block:: python

        property_type_inputs = format_to_property_type_inputs(
            data=property_type_definitions,
        )
    """
    return [
        format_to_property_type_input(property_definition)
        for property_definition in data
    ]


def format_to_project_type(project_type_fragment: ProjectTypeFragment) -> ProjectType:
    """This function gets `psym.graphql.fragment.project_type.ProjectTypeFragment` object as argument
    and formats it to `psym.common.data_class.ProjectType` object

        :param project_type_fragment: Existing project type fragment object
        :type project_type_fragment: :class:`~psym.graphql.fragment.project_type.ProjectTypeFragment`

        :return: ProjectType object
        :rtype: :class:`~psym.common.data_class.ProjectType`

        **Example**

        .. code-block:: python

            project_type = format_to_project_type(
                project_type_fragment=project_type_fragment,
            )
    """
    return ProjectType(
        id=project_type_fragment.id,
        name=project_type_fragment.name,
        description=project_type_fragment.description,
        property_types=format_to_property_definitions(project_type_fragment.properties),
        work_order_definitions=[
            WorkOrderDefinition(
                id=wod.id if wod.id else None,
                definition_index=wod.index if wod.index else None,
                work_order_type_id=wod.type.id,
            )
            for wod in project_type_fragment.workOrders
        ],
    )


def format_to_project(project_fragment: ProjectFragment) -> Project:
    """This function gets `psym.graphql.fragment.project.ProjectFragment` object as argument
    and formats it to `psym.common.data_class.Project` object

        :param project_fragment: Existing project fragment object
        :type project_fragment: :class:`~psym.graphql.fragment.project_type.ProjectFragment`

        :return: Project object
        :rtype: :class:`~psym.common.data_class.Project`

        **Example**

        .. code-block:: python

            project = format_to_project(
                project_fragment=project_fragment,
            )
    """
    work_orders = []
    if project_fragment.workOrders:
        work_orders = [format_to_work_order(wo) for wo in project_fragment.workOrders]
    return Project(
        id=project_fragment.id,
        name=project_fragment.name,
        description=project_fragment.description,
        priority=project_fragment.priority,
        created_by=project_fragment.createdBy.id
        if project_fragment.createdBy
        else None,
        project_type_name=project_fragment.type.name,
        project_type_id=project_fragment.type.id,
        location_id=project_fragment.location.id if project_fragment.location else None,
        work_orders=work_orders,
        properties=project_fragment.properties,
    )


def format_to_equipment_port_type(
    equipment_port_type_fragment: EquipmentPortTypeFragment,
) -> EquipmentPortType:
    """This function gets `psym.graphql.fragment.equipment_port_type.EquipmentPortTypeFragment` object as argument
    and formats it to `psym.common.data_class.EquipmentPortType` object

        :param project_type_fragment: Existing equipment port type fragment object
        :type project_type_fragment: :class:`~psym.graphql.fragment.equipment_port_type.EquipmentPortTypeFragment`

        :return: EquipmentPortType object
        :rtype: :class:`~psym.common.data_class.EquipmentPortType`

        **Example**

        .. code-block:: python

            equipment_port_type = format_to_equipment_port_type(
                equipment_port_type_fragment=equipment_port_type_fragment,
            )
    """
    return EquipmentPortType(
        id=equipment_port_type_fragment.id,
        name=equipment_port_type_fragment.name,
        property_types=format_to_property_definitions(
            equipment_port_type_fragment.propertyTypes
        ),
        link_property_types=format_to_property_definitions(
            equipment_port_type_fragment.linkPropertyTypes
        ),
    )


def format_to_work_order_type(
    work_order_type_fragment: WorkOrderTypeFragment,
) -> WorkOrderType:
    """This function gets `psym.graphql.fragment.work_order_type.WorkOrderTypeFragment` object as argument
    and formats it to `psym.common.data_class.WorkOrderType` object

        :param work_order_type_fragment: Existing work order type fragment object
        :type work_order_type_fragment: :class:`~psym.graphql.fragment.work_order_type.WorkOrderTypeFragment`

        :return: WorkOrderType object
        :rtype: :class:`~psym.common.data_class.WorkOrderType`

        **Example**

        .. code-block:: python

            work_order_type = format_to_work_order_type(
                work_order_type_fragment=work_order_type_fragment,
            )
    """
    return WorkOrderType(
        id=work_order_type_fragment.id,
        name=work_order_type_fragment.name,
        description=work_order_type_fragment.description,
        property_types=format_to_property_definitions(
            work_order_type_fragment.propertyTypes
        ),
    )


def format_to_work_order(work_order_fragment: WorkOrderFragment) -> WorkOrder:
    """This function gets `psym.graphql.fragment.work_order.WorkOrderFragment` object as argument
    and formats it to `psym.common.data_class.WorkOrder` object

        :param work_order_fragment: Existing work order fragment object
        :type work_order_fragment: :class:`~psym.graphql.fragment.work_order.WorkOrderFragment`

        :return: WorkOrder object
        :rtype: :class:`~psym.common.data_class.WorkOrder`

        **Example**

        .. code-block:: python

            work_order = format_to_work_order(
                work_order_fragment=work_order_fragment,
            )
    """
    return WorkOrder(
        id=work_order_fragment.id,
        name=work_order_fragment.name,
        description=work_order_fragment.description,
        work_order_type_name=work_order_fragment.workOrderType.name,
        location_id=work_order_fragment.location.id
        if work_order_fragment.location
        else None,
        project_id=work_order_fragment.project.id
        if work_order_fragment.project
        else None,
        properties=work_order_fragment.properties,
        owner_id=work_order_fragment.owner.id,
        assignee_id=work_order_fragment.assignedTo.id
        if work_order_fragment.assignedTo
        else None,
        status=work_order_fragment.status,
        priority=work_order_fragment.priority,
        organization=work_order_fragment.organizationFk
    )


def format_to_location_type(
    location_type_fragment: LocationTypeFragment,
) -> LocationType:
    """This function gets `psym.graphql.fragment.location_type.LocationTypeFragment` object as argument
    and formats it to `psym.common.data_class.LocationType` object

        :param location_type_fragment: Existing location type fragment object
        :type location_type_fragment: :class:`~psym.graphql.fragment.location_type.LocationTypeFragment`

        :return: LocationType object
        :rtype: :class:`~psym.common.data_class.LocationType`

        **Example**

        .. code-block:: python

            location_type = format_to_location_type(
                location_type_fragment=location_type_fragment,
            )
    """
    return LocationType(
        name=location_type_fragment.name,
        id=location_type_fragment.id,
        property_types=format_to_property_definitions(
            location_type_fragment.propertyTypes
        ),
        map_type=location_type_fragment.mapType,
        map_zoom_level=location_type_fragment.mapZoomLevel,
        is_site=location_type_fragment.isSite,
    )


def format_to_location(location_fragment: LocationFragment) -> Location:
    """This function gets `psym.graphql.fragment.location.LocationFragment` object as argument
    and formats it to `psym.common.data_class.Location` object

        :param location_fragment: Existing location fragment object
        :type location_fragment: :class:`~psym.graphql.fragment.location.LocationFragment`

        :return: Location object
        :rtype: :class:`~psym.common.data_class.Location`

        **Example**

        .. code-block:: python

            location = format_to_location(
                location_fragment=location_fragment,
            )
    """
    return Location(
        id=location_fragment.id,
        name=location_fragment.name,
        latitude=location_fragment.latitude,
        longitude=location_fragment.longitude,
        external_id=location_fragment.externalId,
        location_type_name=location_fragment.locationType.name,
        properties=location_fragment.properties,
    )


def format_to_equipment_type(
    equipment_type_fragment: EquipmentTypeFragment,
) -> EquipmentType:
    """This function gets `psym.graphql.fragment.equipment_type.EquipmentTypeFragment` object as argument
    and formats it to `psym.common.data_class.EquipmentType` object

        :param equipment_type_fragment: Existing equipment type fragment object
        :type equipment_type_fragment: :class:`~psym.graphql.fragment.equipment_type.EquipmentTypeFragment`

        :return: EquipmentType object
        :rtype: :class:`~psym.common.data_class.EquipmentType`

        **Example**

        .. code-block:: python

            equipment_type = format_to_equipment_type(
                equipment_type_fragment=equipment_type_fragment,
            )
    """
    return EquipmentType(
        name=equipment_type_fragment.name,
        category=equipment_type_fragment.category,
        id=equipment_type_fragment.id,
        property_types=format_to_property_definitions(
            equipment_type_fragment.propertyTypes
        ),
        position_definitions=equipment_type_fragment.positionDefinitions,
        port_definitions=equipment_type_fragment.portDefinitions,
    )


def format_to_equipment(equipment_fragment: EquipmentFragment) -> Equipment:
    """This function gets `psym.graphql.fragment.equipment.EquipmentFragment` object as argument
    and formats it to `psym.common.data_class.Equipment` object

        :param equipment_fragment: Existing equipment type fragment object
        :type equipment_fragment: :class:`~psym.graphql.fragment.equipment.EquipmentFragment`

        :return: Equipment object
        :rtype: :class:`~psym.common.data_class.Equipment`

        **Example**

        .. code-block:: python

            equipment = format_to_equipment(
                equipment_fragment=equipment_fragment,
            )
    """
    return Equipment(
        id=equipment_fragment.id,
        external_id=equipment_fragment.externalId,
        name=equipment_fragment.name,
        equipment_type_name=equipment_fragment.equipmentType.name,
        properties=equipment_fragment.properties,
    )


def format_to_service_type(service_type_fragment: ServiceTypeFragment) -> ServiceType:
    """This function gets `psym.graphql.fragment.equipment_type.ServiceTypeFragment` object as argument
    and formats it to `psym.common.data_class.ServiceType` object

        :param service_type_fragment: Existing service type fragment object
        :type service_type_fragment: :class:`~psym.graphql.fragment.equipment_type.ServiceTypeFragment`

        :return: ServiceType object
        :rtype: :class:`~psym.common.data_class.ServiceType`

        **Example**

        .. code-block:: python

            service_type = format_to_service_type(
                service_type_fragment=service_type_fragment,
            )
    """
    definitions = []
    if service_type_fragment.endpointDefinitions:
        definitions = [
            ServiceEndpointDefinition(
                id=definition.id,
                name=definition.name,
                endpoint_definition_index=definition.index,
                role=definition.role,
                equipment_type_id=definition.equipmentType.id,
            )
            for definition in service_type_fragment.endpointDefinitions
        ]
    return ServiceType(
        id=service_type_fragment.id,
        name=service_type_fragment.name,
        has_customer=service_type_fragment.hasCustomer,
        property_types=format_to_property_definitions(
            service_type_fragment.propertyTypes
        ),
        endpoint_definitions=definitions,
    )



#!/usr/bin/env python3
# @generated AUTOGENERATED file. Do not Change!

from dataclasses import dataclass, field as _field
from functools import partial
from ...config import custom_scalars, datetime
from numbers import Number
from typing import Any, AsyncGenerator, Dict, List, Generator, Optional

from dataclasses_json import DataClassJsonMixin, config

from gql_client.runtime.enum_utils import enum_field_metadata
from ..enum.check_list_item_enum_selection_mode import CheckListItemEnumSelectionMode
from ..enum.check_list_item_type import CheckListItemType
from ..enum.yes_no_response import YesNoResponse

from ..input.file_input import FileInput
from ..input.survey_cell_scan_data import SurveyCellScanData
from ..input.survey_wi_fi_scan_data import SurveyWiFiScanData


@dataclass(frozen=True)
class CheckListItemInput(DataClassJsonMixin):
    title: str
    type: CheckListItemType = _field(metadata=enum_field_metadata(CheckListItemType))
    files: List[FileInput]
    wifiData: List[SurveyWiFiScanData]
    cellData: List[SurveyCellScanData]
    id: Optional[str] = None
    index: Optional[int] = None
    isMandatory: Optional[bool] = None
    helpText: Optional[str] = None
    enumValues: Optional[str] = None
    enumSelectionMode: Optional[CheckListItemEnumSelectionMode] = None
    selectedEnumValues: Optional[str] = None
    stringValue: Optional[str] = None
    checked: Optional[bool] = None
    yesNoResponse: Optional[YesNoResponse] = None



#!/usr/bin/env python3
# Copyright (c) 2004-present Facebook All rights reserved.
# Use of this source code is governed by a BSD-style
# license that can be found in the LICENSE file.




from psym.client import SymphonyClient
from psym.common.data_class import KqiCategory

from ..graphql.input.edit_kqi_category_input import EditKqiCategoryInput
from ..graphql.input.add_kqi_category_input import AddKqiCategoryInput
from ..graphql.mutation.add_kqi_category import addKqiCategory
from ..graphql.mutation.edit_kqi_category import EditKqiCategory
from ..graphql.input.edit_kqi_category_input import EditKqiCategoryInput
from ..graphql.query.kqi_category import kqiCategories
from ..graphql.mutation.remove_kqi_category import removeKqiCategory
from psym.common.constant import PAGINATION_STEP
from typing import Any, Dict, Iterator, List, Optional



def add_kqi_category(
    client: SymphonyClient, name: str
) -> KqiCategory:
   
    kqi_category_input = AddKqiCategoryInput(name=name)
    result = addKqiCategory.execute(client, input=kqi_category_input)
    return KqiCategory(name=result.name, id=result.id)


def edit_kqi_category(
    client: SymphonyClient,
    kpicategory: KqiCategory,
    new_name: Optional[str] = None,
) -> None:
    params: Dict[str, Any] = {}
    if new_name is not None:
        params.update({"_name_": new_name})
    if new_name is not None:
        EditKqiCategory.execute(client, input=EditKqiCategoryInput(id=kpicategory.id, name=new_name))


def get_kqi_categories(client: SymphonyClient) -> Iterator[KqiCategory]:

    kqi_categories = kqiCategories.execute(client, first=PAGINATION_STEP)
    edges = kqi_categories.edges if kqi_categories else []
    while kqi_categories is not None and kqi_categories.pageInfo.hasNextPage:
        kqi_categories = kqiCategories.execute(
            client, after=kqi_categories.pageInfo.endCursor, first=PAGINATION_STEP
        )
        if kqi_categories is not None:
            edges.extend(kqi_categories.edges)

    for edge in edges:
        node = edge.node
        if node is not None:
            yield KqiCategory(
                id=node.id,
                name=node.name,
            )


def delete_kqi_category(client: SymphonyClient, id: str) -> None:
    removeKqiCategory.execute(client, id=id)






#!/usr/bin/env python3
# Copyright (c) 2004-present Facebook All rights reserved.
# Use of this source code is governed by a BSD-style
# license that can be found in the LICENSE file.

from typing import Any, Dict, Iterator, List, Optional

from psym.client import SymphonyClient
from psym.common.constant import SUPERUSER_ROLE, USER_ROLE
from psym.common.data_class import User, organization
from psym.common.data_enum import Entity


from ..exceptions import EntityNotFoundError, assert_ok
from ..graphql.enum.user_role import UserRole
from ..graphql.enum.user_status import UserStatus
from ..graphql.input.edit_user_input import EditUserInput
from ..graphql.mutation.edit_user import EditUserMutation
from ..graphql.query.user import UserQuery
from ..graphql.query.users import UsersQuery



def get_user(client: SymphonyClient, email: str) -> User:
    """Returns `psym.common.data_class.User` object by its email
    :param email: Email address the user registered with
    :type email: str
    :raises:
        * :class:`~psym.exceptions.EntityNotFoundError`: the user was not found
        * FailedOperationException: Internal symphony error
    :return: User object
    :rtype: :class:`~psym.common.data_class.User`
    **Example**
    .. code-block:: python
        user = client.get_user(email="user@test.com")
    """
    user = UserQuery.execute(client, email)
    if user is None:
        raise EntityNotFoundError(entity=Entity.User, entity_name=email)
    return User(
        id=user.id,
        auth_id=user.authID,
        email=user.email,
        status=user.status,
        role=user.role,
        firstName=user.firstName,
        lastName=user.lastName, 
        organization=user.organizationFk
        
    )


def add_user(client: SymphonyClient, 
email: str, 
password: str,
firstName: Optional[str] = None,
lastName: Optional[str] = None,
organization: Optional[str] = None,


) -> User:
    """Adds new user to inventory with its email and password
    :param email: Email address of the user
    :type email: str
    :param password: Password the user would connect with
    :type password: str
    :raises:
        * :class:`~psym.exceptions.EntityNotFoundError`: the user was not created
        * FailedOperationException: Internal symphony error
        * AssertionError: The user was not created
        * HTTPError: Connection error
    :return: User object
    :rtype: :class:`~psym.common.data_class.User`
    **Example**
    .. code-block:: python
        user = client.add_user(email="user@test.com", password="P0ssW!rd0f43")
    """
    resp = client.post(
        "/user/async/",
        {
        
        "email": email, 
        "password": password,
        "role": USER_ROLE, 
        "networkIDs": [], 
        "firstName": firstName,
        "lastName": lastName,
        "organization": organization,
        },
    )
    assert_ok(resp)
    return get_user(client=client, email=email)


def edit_user(
    client: SymphonyClient,
    user_id: str,
    new_organization: Optional[str] = None,
    firstName: Optional[str] = None,
    lastName: Optional[str] = None,
    new_role: Optional[UserRole] = None,
    new_status: Optional[UserRole] = None,

) -> User: 

    user_ = get_user_by_id(client=client, id=user_id)
    firstName = user_.firstName if firstName is None else firstName
    lastName = user_.lastName if lastName is None else lastName
    new_role = user_.role if new_role is None else new_role
    new_status = user_.status if new_status is None else new_status
  
    
    edit_user_input = EditUserInput(
        id=user_id,
        role=new_role,
        status=new_status,
        firstName=firstName,
        lastName=lastName,
        organizationFk=new_organization,
    )
    result = EditUserMutation.execute(client, edit_user_input)
    return User(
    id=result.id,
    auth_id=result.authID,
    firstName=result.firstName, 
    lastName=result.lastName, 
    organization=result.organizationFk,
    status=result.status,
    role=result.role,
    email=result.email
    )




def edit_user_for_password_and_role(
    client: SymphonyClient,
    user: User,
    new_password: Optional[str] = None,
    new_role: Optional[UserRole] = None,

) -> None:
    """Edit user password and role
    :param user: User object
    :type user: :class:`~psym.common.data_class.User`
    :param new_password: New password the user would connect with
    :type new_password: str, optional
    :param new_role: New user role
    :type new_role: str
    :raises:
        * FailedOperationException: Internal symphony error
        * AssertionError: The user was not edited
        * HTTPError: Connection error
    :rtype: None
    **Example**
    .. code-block:: python
        user = client.add_user(email="user@test.com", password="P0ssW!rd0f43")
        client.edit_user(
            user=user,
            new_password="New_Password4Ever",
            new_role=UserRole.ADMIN,
        )
    """
    params: Dict[str, Any] = {}
    if new_password is not None:
        params.update({"password": new_password})
    if new_role is not None:
        params.update(
            {"role": USER_ROLE if new_role == UserRole.USER else SUPERUSER_ROLE}
        )
    resp = client.put(f"/user/set/{user.email}", params)
    assert_ok(resp)
    if new_role is not None:
        EditUserMutation.execute(client, input=EditUserInput(id=user.id, role=new_role))


def deactivate_user(client: SymphonyClient, user: User) -> None:
    """Deactivate the user which would prevent the user from login in to symphony
    Users in symphony are never deleted. Only de-activated.
     :param user: User object
     :type user: :class:`~psym.common.data_class.User`
     :raises:
         FailedOperationException: Internal symphony error
     :rtype: None
     **Example**
     .. code-block:: python
         user = client.get_user(email="user@test.com")
         client.deactivate_user(user=user)
    """
    EditUserMutation.execute(
        client, input=EditUserInput(id=user.id, status=UserStatus.DEACTIVATED)
    )


def activate_user(client: SymphonyClient, user: User) -> None:
    """Activate the user which would allow the user to login again to symphony
    :param user: User object
    :type user: :class:`~psym.common.data_class.User`
    :raises:
        FailedOperationException: Internal symphony error
    :rtype: None
    **Example**
    .. code-block:: python
        user = client.get_user(email="user@test.com")
        client.activate_user(user=user)
    """
    EditUserMutation.execute(
        client, input=EditUserInput(id=user.id, status=UserStatus.ACTIVE)
    )


def get_users(client: SymphonyClient) -> Iterator[User]:
    """Get the list of users in the system (both active and deactivate)
    :raises:
        FailedOperationException: Internal symphony error
    :return: Users Iterator
    :rtype: Iterator[ :class:`~psym.common.data_class.User` ]
    **Example**
    .. code-block:: python
        users = client.get_users()
        for user in users:
            print(user.email)
    """
    result = UsersQuery.execute(client)
    if result is None:
        return
    for edge in result.edges:
        node = edge.node
        if node is not None:
            yield User(
                id=node.id,
                auth_id=node.authID,
                email=node.email,
                firstName=node.firstName ,
                lastName= node.lastName,
                status=node.status,
                role=node.role,
                organization=node.organizationFk
            )

def get_user_by_email(client: SymphonyClient, email: str) -> User:
    user_email = get_users(client=client)
    for user_ in user_email:
        if user_.email == email:
            return user_
    raise EntityNotFoundError(entity=Entity.User, entity_email=email)

def get_user_by_id(client: SymphonyClient, id: str) -> User:
    user_id = get_users(client=client)
    for user_ in user_id:
        if user_.id == id:
            return user_
    raise EntityNotFoundError(entity=Entity.User, entity_id=id)



def get_active_users(client: SymphonyClient) -> List[User]:
    """Get the list of the active users in the system
    :raises:
        FailedOperationException: Internal symphony error
    :return: Users List
    :rtype: List[ :class:`~psym.common.data_class.User` ]
    **Example**
    .. code-block:: python
        users = client.get_active_users()
        for user in users:
            print(user.email)
    """
    users = get_users(client=client)
    return [user for user in users if user.status == UserStatus.ACTIVE]


#!/usr/bin/env python3
# Copyright (c) 2004-present Facebook All rights reserved.
# Use of this source code is governed by a BSD-style
# license that can be found in the LICENSE file.



from psym.common.data_class import RecommendationsCategory
from psym.client import SymphonyClient

from ..graphql.input.edit_recommendations_category_input import EditRecommendationsCategoryInput
from ..graphql.input.add_recommendations_category_input import AddRecommendationsCategoryInput
from ..graphql.mutation.add_recommendations_category import addRecommendationsCategory
from ..graphql.mutation.edit_recommendations_category import editRecommendationsCategory
from ..graphql.mutation.remove_recommendations_category import removeRecommendationCategory
from ..graphql.query.recommendation_categories import RecommendationsCategories
from psym.common.constant import PAGINATION_STEP
from typing import Any, Dict, Iterator, List, Optional




def add_recommendations_category(
    client: SymphonyClient, name: str
) -> RecommendationsCategory:
   
    recommendations_category_input = AddRecommendationsCategoryInput(name=name)
    result = addRecommendationsCategory.execute(client, input=recommendations_category_input)
    return RecommendationsCategory(name=result.name, id=result.id)

def edit_recommendations_category(
    client: SymphonyClient,
    recommendation_category: RecommendationsCategory,
    new_name: Optional[str] = None,
) -> None:
    params: Dict[str, Any] = {}
    if new_name is not None:
        params.update({"_name_": new_name})
    if new_name is not None:
        editRecommendationsCategory.execute(client, input=EditRecommendationsCategoryInput(id=recommendation_category.id, name=new_name))


def get_recommendations_categoryes(client: SymphonyClient) -> Iterator[RecommendationsCategory]:

    recommendations_categoryess_ = RecommendationsCategories.execute(client, first=PAGINATION_STEP)
    edges = recommendations_categoryess_.edges if recommendations_categoryess_ else []
    while recommendations_categoryess_ is not None and recommendations_categoryess_.pageInfo.hasNextPage:
        recommendations_categoryess_ = RecommendationsCategories.execute(
            client, after=recommendations_categoryess_.pageInfo.endCursor, first=PAGINATION_STEP
        )
        if recommendations_categoryess_ is not None:
            edges.extend(recommendations_categoryess_.edges)

    for edge in edges:
        node = edge.node
        if node is not None:
            yield RecommendationsCategory(
                id=node.id,
                name=node.name,
            )


def remove_recommendations_category(client: SymphonyClient, id: str) -> None:
    removeRecommendationCategory.execute(client, id=id)

    


#!/usr/bin/env python3
# Copyright (c) 2004-present Facebook All rights reserved.
# Use of this source code is governed by a BSD-style
# license that can be found in the LICENSE file.


from psym.client import SymphonyClient
from psym.common.data_class import rule, threshold, eventSeverity, ruleType

#from ..graphql.input.edit_rule_input import EditRuleInput 
from ..graphql.input.add_rule_input import AddRuleInput
from ..graphql.mutation.add_rule import addRule
#from ..graphql.mutation.edit_rule import editRule
#from ..graphql.mutation.remove_rule import removerule
#from ..graphql.query.rules import rules
from psym.common.constant import PAGINATION_STEP
from typing import Any, Dict, Iterator, List, Optional




def add_rule(
    client: SymphonyClient, 
    name: str,
    gracePeriod: int,
    ruleType: str,
    eventTypeName: str,
    specificProblem: str,
    additionalInfo: str,
    status: bool,
    eventSeverity: str,
    threshold: str
) -> rule:
   

    rule_input = AddRuleInput(
    name=name,
    gracePeriod=gracePeriod,
    ruleType=ruleType,
    eventTypeName=eventTypeName,
    specificProblem=specificProblem,
    additionalInfo=additionalInfo,
    status=status,
    eventSeverity=eventSeverity,
    threshold=threshold
    

    )

    result = addRule.execute(client, input=rule_input)

    return rule(
    name=result.name, 
    id=result.id, 
    gracePeriod=result.gracePeriod,
    ruleType=result.ruleType,
    eventTypeName=result.eventTypeName,
    specificProblem=result.specificProblem,
    additionalInfo=result.additionalInfo,
    status=result.status,
    eventSeverity=result.eventSeverity,
    threshold=result.threshold
    )



#!/usr/bin/env python3
# @generated AUTOGENERATED file. Do not Change!

from dataclasses import dataclass, field as _field
from functools import partial
from ...config import custom_scalars, datetime
from numbers import Number
from typing import Any, AsyncGenerator, Dict, List, Generator, Optional

from dataclasses_json import DataClassJsonMixin, config

from gql_client.runtime.enum_utils import enum_field_metadata
from ..enum.action_type_id import ActionTypeId

from ..input.block_u_i_representation_input import BlockUIRepresentationInput
from ..input.variable_expression_input import VariableExpressionInput


@dataclass(frozen=True)
class ActionBlockInput(DataClassJsonMixin):
    cid: str
    actionType: ActionTypeId = _field(metadata=enum_field_metadata(ActionTypeId))
    params: List[VariableExpressionInput]
    uiRepresentation: Optional[BlockUIRepresentationInput] = None



#!/usr/bin/env python3
# Copyright (c) 2004-present Facebook All rights reserved.
# Use of this source code is governed by a BSD-style
# license that can be found in the LICENSE file.

from typing import Optional

from psym.client import SymphonyClient
from psym.common.data_class import Flow, FlowDraft, FlowInstance
from psym.graphql.enum.flow_new_instances_policy import FlowNewInstancesPolicy
from psym.graphql.input.add_flow_draft_input import AddFlowDraftInput
from psym.graphql.input.import_flow_draft_input import ImportFlowDraftInput
from psym.graphql.input.publish_flow_input import PublishFlowInput
from psym.graphql.input.start_block_input import StartBlockInput
from psym.graphql.input.start_flow_input import StartFlowInput
from psym.graphql.mutation.add_flow_draft import AddFlowDraftMutation
from psym.graphql.mutation.import_flow_draft import ImportFlowDraftMutation
from psym.graphql.mutation.publish_flow import PublishFlowMutation
from psym.graphql.mutation.start_flow import StartFlowMutation


def add_flow_draft(client: SymphonyClient, name: str) -> FlowDraft:
    """This function add flow draft

    :param name: Name of the flow draft
    :type name: str

    :raises:
        * FailedOperationException: Internal symphony error

    :return: FlowDraft object
    :rtype: :class:`~psym.common.data_class.FlowDraft`

    **Example**

    .. code-block:: python

        draft = client.add_flow_draft(name="Transport Deployment")
    """
    flow_draft = AddFlowDraftMutation.execute(
        client, AddFlowDraftInput(name=name, endParamDefinitions=[])
    )
    return FlowDraft(id=flow_draft.id, name=flow_draft.name)


def import_flow_draft(
    client: SymphonyClient, id: str, name: str, start_block_cid: Optional[str]
) -> FlowDraft:
    """This function imports an existing flow draft with draft details and blocks

    :param id: Id of flow draft to edit
    :type id: str
    :param name: New name of the flow draft
    :type name: str
    :param start_block_cid: Client ID of the start block to create in flow draft
    :type start_block_cid: str, optional

    :raises:
        * FailedOperationException: Internal symphony error

    :return: FlowDraft object
    :rtype: :class:`~psym.common.data_class.FlowDraft`

    **Example**

    .. code-block:: python

        draft = client.add_flow_draft(name="Transport Deployment")
        new_draft = client.import_flow_draft(id=draft.id, name=draft.name, start_block_cid="Start")
    """
    start_block_input = (
        StartBlockInput(cid=start_block_cid, paramDefinitions=[])
        if start_block_cid
        else None
    )
    flow_draft = ImportFlowDraftMutation.execute(
        client,
        ImportFlowDraftInput(
            id=id,
            name=name,
            endParamDefinitions=[],
            startBlock=start_block_input,
            endBlocks=[],
            decisionBlocks=[],
            gotoBlocks=[],
            subflowBlocks=[],
            triggerBlocks=[],
            actionBlocks=[],
            trueFalseBlocks=[],
            connectors=[],
        ),
    )
    return FlowDraft(id=flow_draft.id, name=flow_draft.name)


def publish_flow(client: SymphonyClient, flow_draft_id: str) -> Flow:
    """This function publishes flow draft which creates flow with flow draft content and delete the flow draft

    :param flow_draft_id: Id of flow draft to publish
    :type flow_draft_id: str

    :raises:
        * FailedOperationException: Internal symphony error

    :return: Flow object
    :rtype: :class:`~psym.common.data_class.Flow`

    **Example**

    .. code-block:: python

        draft = client.add_flow_draft(name="Transport Deployment")
        new_draft = client.import_flow_draft(id=draft.id, name=draft.name, start_block_name="Start")
        flow = client.publish_flow(flow_draft_id=new_draft.id, flowInstancesPolicy.ENABLED)
    """
    flow = PublishFlowMutation.execute(
        client,
        PublishFlowInput(
            flowDraftID=flow_draft_id,
            flowInstancesPolicy=FlowNewInstancesPolicy.ENABLED,
        ),
    )
    return Flow(id=flow.id, name=flow.name)


def start_flow(client: SymphonyClient, flow_id: str) -> FlowInstance:
    """This function starts a flow and create flow instance of it

    :param flow_id: Id of flow to start
    :type flow_id: str

    :raises:
        * FailedOperationException: Internal symphony error

    :return: FlowInstance object
    :rtype: :class:`~psym.common.data_class.FlowInstance`

    **Example**

    .. code-block:: python

        draft = client.add_flow_draft(name="Transport Deployment")
        new_draft = client.import_flow_draft(id=draft.id, name=draft.name, start_block_name="Start")
        flow = client.publish_flow(flow_draft_id=new_draft.id)
        flow_instance = client.start_flow(flow_id=flow.id)
    """
    flow_instance = StartFlowMutation.execute(
        client, StartFlowInput(flowID=flow_id, params=[])
    )
    return FlowInstance(id=flow_instance.id, status=flow_instance.status)



#!/usr/bin/env python3
# Copyright (c) 2004-present Facebook All rights reserved.
# Use of this source code is governed by a BSD-style
# license that can be found in the LICENSE file.

from typing import Iterator, Optional

from psym.client import SymphonyClient
from psym.common.data_class import Customer

from ..graphql.input.add_customer_input import AddCustomerInput
from ..graphql.mutation.add_customer import AddCustomerMutation
from ..graphql.mutation.remove_customer import RemoveCustomerMutation
from ..graphql.query.customers import CustomersQuery


def add_customer(
    client: SymphonyClient, name: str, external_id: Optional[str]
) -> Customer:
    """This function adds Customer.

    :param name: Customer name
    :type name: str
    :param external_id: Customer external ID
    :type external_id: str, optional

    :return: Customer object
    :rtype: :class:`~psym.common.data_class.Customer`

    **Example 1**

    .. code-block:: python

        new_customers = client.add_customer(name="new_customer")

    **Example 2**

    .. code-block:: python

        new_customers = client.add_customer(
            name="new_customer",
            external_id="12345678"
        )
    """
    customer_input = AddCustomerInput(name=name, externalId=external_id)
    result = AddCustomerMutation.execute(client, input=customer_input)
    return Customer(name=result.name, id=result.id, external_id=result.externalId)


def get_all_customers(client: SymphonyClient) -> Iterator[Customer]:

    """This function returns all Customers.

    :return: Customers Iterator
    :rtype: Iterator[ :class:`~psym.common.data_class.Customer` ]

    **Example**

    .. code-block:: python

        customers = client.get_all_customers()
    """
    customers = CustomersQuery.execute(client)
    if not customers:
        return
    for customer in customers.edges:
        node = customer.node
        if node:
            yield Customer(name=node.name, id=node.id, external_id=node.externalId)


def delete_customer(client: SymphonyClient, customer: Customer) -> None:
    """This function delete Customer.

    :param name: Customer name
    :type name: :class:`~psym.common.data_class.Customer`
    :rtype: None

    **Example**

    .. code-block:: python

        client.delete_customer(customer)
    """
    RemoveCustomerMutation.execute(client, id=customer.id)



#!/usr/bin/env python3
# Copyright (c) 2004-present Facebook All rights reserved.
# Use of this source code is governed by a BSD-style
# license that can be found in the LICENSE file.




from psym.client import SymphonyClient
from psym.common.data_class import KqiPerspective

from ..graphql.input.edit_kqi_perspective_input import EditKqiPerspectiveInput
from ..graphql.input.add_kqi_perspective_input import AddKqiPerspectiveInput
from ..graphql.input.edit_kqi_perspective_input import EditKqiPerspectiveInput
from ..graphql.mutation.add_kqi_perspective import addKqiPerspective
from ..graphql.mutation.edit_kqi_perspective import editKqiPerspective
from ..graphql.query.kqi_perspective import kqiPerspectives
from ..graphql.mutation.remove_kqi_perspective import removeKqiPerspective
from psym.common.constant import PAGINATION_STEP
from typing import Any, Dict, Iterator, List, Optional




def add_kqi_perspective(
    client: SymphonyClient, name: str
) -> KqiPerspective:
   
    kqi_perspective_input = AddKqiPerspectiveInput(name=name)
    result = addKqiPerspective.execute(client, input=kqi_perspective_input)
    return KqiPerspective(name=result.name, id=result.id)


def edit_kqi_perspective(
    client: SymphonyClient,
    kqiperspective: KqiPerspective,
    new_name: Optional[str] = None,
) -> None:
    params: Dict[str, Any] = {}
    if new_name is not None:
        params.update({"_name_": new_name})
    if new_name is not None:
        editKqiPerspective.execute(client, input=EditKqiPerspectiveInput(id=kqiperspective.id, name=new_name))


def get_kqi_perspectives(client: SymphonyClient) -> Iterator[KqiPerspective]:

    kqi_perspectives = kqiPerspectives.execute(client, first=PAGINATION_STEP)
    edges = kqi_perspectives.edges if kqi_perspectives else []
    while kqi_perspectives is not None and kqi_perspectives.pageInfo.hasNextPage:
        kqi_perspectives = kqiPerspectives.execute(
            client, after=kqi_perspectives.pageInfo.endCursor, first=PAGINATION_STEP
        )
        if kqi_perspectives is not None:
            edges.extend(kqi_perspectives.edges)

    for edge in edges:
        node = edge.node
        if node is not None:
            yield KqiPerspective(
                id=node.id,
                name=node.name,
            )


def delete_kqi_perspective(client: SymphonyClient, id: str) -> None:
    removeKqiPerspective.execute(client, id=id)






#!/usr/bin/env python3
# @generated AUTOGENERATED file. Do not Change!

from dataclasses import dataclass, field as _field
from ...config import custom_scalars, datetime
from gql_client.runtime.variables import encode_variables
from gql import gql, Client
from gql.transport.exceptions import TransportQueryError
from functools import partial
from numbers import Number
from typing import Any, AsyncGenerator, Dict, List, Generator, Optional
from time import perf_counter
from dataclasses_json import DataClassJsonMixin, config

from gql_client.runtime.enum_utils import enum_field_metadata
from ..enum.user_role import UserRole
from ..enum.user_status import UserStatus

# fmt: off
QUERY: List[str] = ["""
fragment UserFragment on User {
  id
  authID
  email
  firstName
  lastName
  status
  role
  organizationFk{id}
  
}

"""]

@dataclass(frozen=True)
class UserFragment(DataClassJsonMixin):
    @dataclass(frozen=True)
    class Organization(DataClassJsonMixin):
        id: str

    id: str
    authID: str
    email: str
    firstName: str
    lastName: str
    status: UserStatus = _field(metadata=enum_field_metadata(UserStatus))
    role: UserRole = _field(metadata=enum_field_metadata(UserRole))
    organizationFk: Optional[Organization]



#!/usr/bin/env python3
# @generated AUTOGENERATED file. Do not Change!

from dataclasses import dataclass, field as _field
from functools import partial
from ...config import custom_scalars, datetime
from numbers import Number
from typing import Any, AsyncGenerator, Dict, List, Generator, Optional

from dataclasses_json import DataClassJsonMixin, config

from gql_client.runtime.enum_utils import enum_field_metadata
from ..enum.survey_status import SurveyStatus

from ..input.survey_question_response import SurveyQuestionResponse


@dataclass(frozen=True)
class SurveyCreateData(DataClassJsonMixin):
    name: str
    completionTimestamp: int
    locationID: str
    surveyResponses: List[SurveyQuestionResponse]
    ownerName: Optional[str] = None
    creationTimestamp: Optional[int] = None
    status: Optional[SurveyStatus] = None



#!/usr/bin/env python3
# @generated AUTOGENERATED file. Do not Change!

from dataclasses import dataclass, field as _field
from ...config import custom_scalars, datetime
from gql_client.runtime.variables import encode_variables
from gql import gql, Client
from gql.transport.exceptions import TransportQueryError
from functools import partial
from numbers import Number
from typing import Any, AsyncGenerator, Dict, List, Generator, Optional
from time import perf_counter
from dataclasses_json import DataClassJsonMixin, config

from ..input.add_kqi_temporal_frequency_input import AddKqiTemporalFrequencyInput


# fmt: off
QUERY: List[str] = ["""
mutation addKqiTemporalFrequency($input: AddKqiTemporalFrequencyInput!) {
  addKqiTemporalFrequency(input: $input) {
    id
    name
  }
}
"""
]


class addKqiTemporalFrequency:
    @dataclass(frozen=True)
    class addKqiTemporalFrequencyData(DataClassJsonMixin):
        @dataclass(frozen=True)
        class KqiTemporalFrequency(DataClassJsonMixin):
            id: str
            name: str

        addKqiTemporalFrequency: KqiTemporalFrequency

    # fmt: off
    @classmethod
    def execute(cls, client: Client, input: AddKqiTemporalFrequencyInput) -> addKqiTemporalFrequencyData.KqiTemporalFrequency:
        variables: Dict[str, Any] = {"input": input}
        new_variables = encode_variables(variables, custom_scalars)
        response_text = client.execute(
            gql("".join(set(QUERY))), variable_values=new_variables
        )
        res = cls.addKqiTemporalFrequencyData.from_dict(response_text)
        return res.addKqiTemporalFrequency

    # fmt: off
    @classmethod
    async def execute_async(cls, client: Client, input: AddKqiTemporalFrequencyInput) -> addKqiTemporalFrequencyData.KqiTemporalFrequency:
        variables: Dict[str, Any] = {"input": input}
        new_variables = encode_variables(variables, custom_scalars)
        response_text = await client.execute_async(
            gql("".join(set(QUERY))), variable_values=new_variables
        )
        res = cls.addKqiTemporalFrequencyData.from_dict(response_text)
        return res.addKqiTemporalFrequency



#!/usr/bin/env python3
# Copyright (c) 2004-present Facebook All rights reserved.
# Use of this source code is governed by a BSD-style
# license that can be found in the LICENSE file.


from psym.client import SymphonyClient
from psym.common.data_class import CounterFamily

from ..graphql.input.edit_counter_family_input import EditCounterFamilyInput
from ..graphql.input.add_counter_family_input import AddCounterFamilyInput
from ..graphql.mutation.add_counter_family import addCounterFamily
from ..graphql.mutation.edit_counter_family import editCounterFamily
from ..graphql.mutation.remove_counter_family import removeCounterFamily
from ..graphql.query.counter_families import counterFamilies
from psym.common.constant import PAGINATION_STEP
from typing import Any, Dict, Iterator, List, Optional




def add_counter_family(
    client: SymphonyClient, name: str
) -> CounterFamily:
   
    counter_family_input = AddCounterFamilyInput(name=name)
    result = addCounterFamily.execute(client, input=counter_family_input)
    return CounterFamily(name=result.name, id=result.id)

def edit_counter_family(
    client: SymphonyClient,
    counter_family: CounterFamily,
    new_name: Optional[str] = None,
) -> None:
    params: Dict[str, Any] = {}
    if new_name is not None:
        params.update({"_name_": new_name})
    if new_name is not None:
        editCounterFamily.execute(client, input=EditCounterFamilyInput(id=counter_family.id, name=new_name))


def get_counter_families(client: SymphonyClient) -> Iterator[CounterFamily]:

    counter_familiess_ = counterFamilies.execute(client, first=PAGINATION_STEP)
    edges = counter_familiess_.edges if counter_familiess_ else []
    while counter_familiess_ is not None and counter_familiess_.pageInfo.hasNextPage:
        counter_familiess_ = counterFamilies.execute(
            client, after=counter_familiess_.pageInfo.endCursor, first=PAGINATION_STEP
        )
        if counter_familiess_ is not None:
            edges.extend(counter_familiess_.edges)

    for edge in edges:
        node = edge.node
        if node is not None:
            yield CounterFamily(
                id=node.id,
                name=node.name,
            )


def remove_counter_family(client: SymphonyClient, id: str) -> None:
    removeCounterFamily.execute(client, id=id)


#!/usr/bin/env python3
# @generated AUTOGENERATED file. Do not Change!

from dataclasses import dataclass, field as _field
from ...config import custom_scalars, datetime
from gql_client.runtime.variables import encode_variables
from gql import gql, Client
from gql.transport.exceptions import TransportQueryError
from functools import partial
from numbers import Number
from typing import Any, AsyncGenerator, Dict, List, Generator, Optional
from time import perf_counter
from dataclasses_json import DataClassJsonMixin, config

from gql_client.runtime.enum_utils import enum_field_metadata
from ..enum.survey_question_type import SurveyQuestionType

# fmt: off
QUERY: List[str] = ["""
fragment SurveyQuestionFragment on SurveyQuestion {
  formName
  questionFormat
  questionText
  boolData
  emailData
  latitude
  longitude
  phoneData
  textData
  floatData
  intData
  dateData
}

"""]

@dataclass(frozen=True)
class SurveyQuestionFragment(DataClassJsonMixin):
    formName: Optional[str]
    questionFormat: Optional[SurveyQuestionType] = _field(metadata=enum_field_metadata(SurveyQuestionType))
    questionText: str
    boolData: Optional[bool]
    emailData: Optional[str]
    latitude: Optional[Number]
    longitude: Optional[Number]
    phoneData: Optional[str]
    textData: Optional[str]
    floatData: Optional[Number]
    intData: Optional[int]
    dateData: Optional[int]



#!/usr/bin/env python3
# Copyright (c) 2004-present Facebook All rights reserved.
# Use of this source code is governed by a BSD-style
# license that can be found in the LICENSE file.

from typing import Iterator, List, Mapping, Optional

from psym._utils import get_graphql_property_type_inputs
from psym.client import SymphonyClient
from psym.common.cache import LOCATION_TYPES
from psym.common.data_class import (
    Location,
    LocationType,
    PropertyDefinition,
    PropertyValue,
)
from psym.common.data_enum import Entity
from psym.common.data_format import (
    format_to_location_type,
    format_to_property_type_inputs,
)

from ..exceptions import EntityNotFoundError
from ..graphql.input.add_location_type_input import AddLocationTypeInput
from ..graphql.input.edit_location_type_input import EditLocationTypeInput
from ..graphql.mutation.add_location_type import AddLocationTypeMutation
from ..graphql.mutation.edit_location_type import EditLocationTypeMutation
from ..graphql.mutation.remove_location_type import RemoveLocationTypeMutation
from ..graphql.query.location_type_details import LocationTypeDetailsQuery
from ..graphql.query.location_type_locations import LocationTypeLocationsQuery
from ..graphql.query.location_types import LocationTypesQuery
from .location import delete_location


def _populate_location_types(client: SymphonyClient) -> None:
    location_types = LocationTypesQuery.execute(client)
    if not location_types:
        return
    edges = location_types.edges
    for edge in edges:
        node = edge.node
        if node:
            LOCATION_TYPES[node.name] = format_to_location_type(
                location_type_fragment=node
            )


def add_location_type(
    client: SymphonyClient,
    name: str,
    properties: List[PropertyDefinition],
    map_type: Optional[str] = None,
    map_zoom_level: int = 8,
    is_site: bool = False,
) -> LocationType:
    """This function creates new location type.

    :param name: Location type name
    :type name: str
    :param properties: List of property definitions
    :type properties: List[ :class:`~psym.common.data_class.PropertyDefinition` ]
    :param map_type: Map type
    :type map_type: str, optional
    :param map_zoom_level: Map zoom level
    :type map_zoom_level: int
    :param is_site: Is site flag
    :type is_site: bool

    :raises:
        FailedOperationException: Internal symphony error

    :return: LocationType object
    :rtype: :class:`~psym.common.data_class.LocationType`

    **Example**

    .. code-block:: python

        location_type = client.add_location_type(
            name="city",
            properties=[
                PropertyDefinition(
                    property_name="Contact",
                    property_kind=PropertyKind.string,
                    default_raw_value=None,
                    is_fixed=True
                )
            ],
            map_zoom_level=5,
        )
    """
    new_property_types = format_to_property_type_inputs(data=properties)
    result = AddLocationTypeMutation.execute(
        client,
        AddLocationTypeInput(
            name=name,
            mapZoomLevel=map_zoom_level,
            mapType=map_type if map_type else None,
            isSite=is_site,
            properties=new_property_types,
            surveyTemplateCategories=[],
        ),
    )

    location_type = format_to_location_type(location_type_fragment=result)
    LOCATION_TYPES[result.name] = location_type
    return location_type


def add_property_types_to_location_type(
    client: SymphonyClient,
    location_type_id: str,
    new_properties: List[PropertyDefinition],
) -> LocationType:
    """This function adds new property types to existing location type.

    :param location_type_id: Existing location type ID
    :type location_type_id: str
    :param new_properties: List of property definitions
    :type new_properties: List[ :class:`~psym.common.data_class.PropertyDefinition` ]

    :raises:
        FailedOperationException: Internal symphony error

    :return: LocationType object
    :rtype: :class:`~psym.common.data_class.LocationType`

    **Example**

    .. code-block:: python

        location_type = client.add_property_types_to_location_type(
            location_type_id="12345678",
            new_properties=[
                PropertyDefinition(
                    property_name="Contact",
                    property_kind=PropertyKind.string,
                    default_raw_value=None,
                    is_fixed=True
                )
            ],
        )
    """
    location_type = get_location_type_by_id(client=client, id=location_type_id)
    new_property_type_inputs = format_to_property_type_inputs(data=new_properties)
    result = EditLocationTypeMutation.execute(
        client,
        EditLocationTypeInput(
            id=location_type.id,
            name=location_type.name,
            mapType=location_type.map_type,
            mapZoomLevel=location_type.map_zoom_level,
            isSite=location_type.is_site,
            properties=new_property_type_inputs,
        ),
    )
    edited = format_to_location_type(location_type_fragment=result)
    LOCATION_TYPES.pop(location_type.name)
    LOCATION_TYPES[edited.name] = edited
    return edited


def edit_location_type(
    client: SymphonyClient,
    location_type_id: str,
    new_name: Optional[str] = None,
    new_properties_defaults: Optional[Mapping[str, PropertyValue]] = None,
    new_map_type: Optional[str] = None,
    new_map_zoom_level: Optional[int] = 8,
    new_is_site: Optional[bool] = False,
) -> LocationType:
    """This function edits existing LocationType.

    :param location_type_id: Existing location type ID
    :type location_type_id: str
    :param new_name: Location type new name
    :type new_name: str, optional
    :param new_properties_defaults: Mapping of property name to property default value

        * str - property name
        * PropertyValue - new default value of the same type for this property

    :type new_properties_defaults: Mapping[str, PropertyValue], optional
    :param map_type: New map type
    :type map_type: str, optional
    :param map_zoom_level: New map zoom level
    :type map_zoom_level: int, optional
    :param new_is_site: New is site flag
    :type new_is_site: bool, optional

    :raises:
        * FailedOperationException: Internal symphony error
        * :class:`~psym.exceptions.EntityNotFoundError`: Location type does not exist

    :return: LocationType
    :rtype: :class:`~psym.common.data_class.LocationType`

    **Example**

    .. code-block:: python

        edited_location_type = client.edit_location_type(
            location_type_id="12345678,
            new_name="New name",
            new_description="New description",
        )
    """
    location_type = get_location_type_by_id(client=client, id=location_type_id)
    new_name = location_type.name if new_name is None else new_name

    new_property_type_inputs = []
    if new_properties_defaults:
        property_types = location_type.property_types
        new_property_type_inputs = get_graphql_property_type_inputs(
            property_types, new_properties_defaults
        )
    result = EditLocationTypeMutation.execute(
        client,
        EditLocationTypeInput(
            id=location_type.id,
            name=new_name,
            mapType=new_map_type,
            mapZoomLevel=new_map_zoom_level,
            isSite=new_is_site,
            properties=new_property_type_inputs,
        ),
    )
    edited = format_to_location_type(location_type_fragment=result)
    LOCATION_TYPES.pop(location_type.name)
    LOCATION_TYPES[edited.name] = edited
    return edited


def get_location_types(client: SymphonyClient) -> Iterator[LocationType]:
    """Get the iterator of location types

    :raises:
        FailedOperationException: Internal symphony error

    :return: LocationType Iterator
    :rtype: Iterator[ :class:`~psym.common.data_class.LocationType` ]

    **Example**

    .. code-block:: python

        location_types = client.get_location_types()
        for location_type in location_types:
            print(location_type.name)
    """
    result = LocationTypesQuery.execute(client)
    if result is None:
        return
    for edge in result.edges:
        node = edge.node
        if node is not None:
            yield format_to_location_type(location_type_fragment=node)


def get_location_type_by_id(client: SymphonyClient, id: str) -> LocationType:
    """This function gets existing LocationType by its ID.

    :param id: Location type ID
    :type id: str

    :raises:
        * FailedOperationException: Internal symphony error
        * :class:`~psym.exceptions.EntityNotFoundError`: Location type does not exist

    :return: Location type
    :rtype: :class:`~psym.common.data_class.LocationType`

    **Example**

    .. code-block:: python

        client.get_location_type_by_id(id="12345678")
    """
    result = LocationTypeDetailsQuery.execute(client, id=id)

    if result is None:
        raise EntityNotFoundError(entity=Entity.WorkOrderType, entity_id=id)

    return format_to_location_type(location_type_fragment=result)


def delete_locations_by_location_type(
    client: SymphonyClient, location_type: LocationType
) -> None:
    """Delete locatons by location type.

    :param location_type: LocationType object
    :type location_type: :class:`~psym.common.data_class.LocationType`

    :raises:
        `psym.exceptions.EntityNotFoundError`: `location_type` does not exist

    :rtype: None

    **Example**

    .. code-block:: python

        client.delete_locations_by_location_type(location_type=location_type)
    """
    location_type_with_locations = LocationTypeLocationsQuery.execute(
        client, id=location_type.id
    )
    if location_type_with_locations is None:
        raise EntityNotFoundError(
            entity=Entity.LocationType, entity_id=location_type.id
        )
    locations = location_type_with_locations.locations
    if locations is None:
        return
    for location in locations.edges:
        node = location.node
        if node:
            delete_location(
                client,
                Location(
                    id=node.id,
                    name=node.name,
                    latitude=node.latitude,
                    longitude=node.longitude,
                    external_id=node.externalId,
                    location_type_name=node.locationType.name,
                    properties=node.properties,
                ),
            )


def delete_location_type_with_locations(
    client: SymphonyClient, location_type: LocationType
) -> None:
    """Delete locaton type with existing locations.

    :param location_type: LocationType object
    :type location_type: :class:`~psym.common.data_class.LocationType`

    :raises:
        `psym.exceptions.EntityNotFoundError`: `location_type` does not exist

    :rtype: None

    **Example**

    .. code-block:: python

        client.delete_location_type_with_locations(location_type=location_type)
    """
    delete_locations_by_location_type(client, location_type)
    delete_location_type(client, location_type_id=location_type.id)


def delete_location_type(client: SymphonyClient, location_type_id: str) -> None:
    """This function deletes LocatoinType.

    :param location_type_id: Location type ID
    :type location_type_id: str

    :raises:
        * FailedOperationException: Internal symphony error
        * :class:`~psym.exceptions.EntityNotFoundError`: Location type does not exist

    **Example**

    .. code-block:: python

        client.delete_location_type(
            location_type_id="12345678"
        )
    """
    location_type = get_location_type_by_id(client=client, id=location_type_id)
    if location_type is None:
        raise EntityNotFoundError(
            entity=Entity.LocationType, entity_id=location_type_id
        )
    RemoveLocationTypeMutation.execute(client, id=location_type_id)
    del LOCATION_TYPES[location_type.name]



#!/usr/bin/env python3
# Copyright (c) 2004-present Facebook All rights reserved.
# Use of this source code is governed by a BSD-style
# license that can be found in the LICENSE file.


from psym.client import SymphonyClient
from psym.common.data_class import comparator

from ..graphql.input.edit_comparator_input import EditComparatorInput
from ..graphql.input.add_comparator_input import AddComparatorInput
from ..graphql.mutation.add_comparator import addComparator
from ..graphql.mutation.edit_comparator import editComparator
from ..graphql.mutation.remove_comparator import removeComparator
from ..graphql.query.comparators import comparators
from psym.common.constant import PAGINATION_STEP
from typing import Any, Dict, Iterator, List, Optional




def add_comparator(
    client: SymphonyClient, name: str
) -> comparator:
   
    comparator_input = AddComparatorInput(name=name)
    result = addComparator.execute(client, input=comparator_input)
    return comparator(name=result.name, id=result.id)

def edit_comparator(
    client: SymphonyClient,
    comparator: comparator,
    new_name: Optional[str] = None,
) -> None:
    params: Dict[str, Any] = {}
    if new_name is not None:
        params.update({"_name_": new_name})
    if new_name is not None:
        editComparator.execute(client, input=EditComparatorInput(id=comparator.id, name=new_name))

def get_comparators(client: SymphonyClient) -> Iterator[comparator]:

    comparators_ = comparators.execute(client, first=PAGINATION_STEP)
    edges = comparators_.edges if comparators_ else []
    while comparators_ is not None and comparators_.pageInfo.hasNextPage:
        comparators_ = comparators.execute(
            client, after=comparators_.pageInfo.endCursor, first=PAGINATION_STEP
        )
        if comparators_ is not None:
            edges.extend(comparators_.edges)

    for edge in edges:
        node = edge.node
        if node is not None:
            yield comparator(
                id=node.id,
                name=node.name,
            )


def remove_comparator(client: SymphonyClient, id: str) -> None:
    removeComparator.execute(client, id=id)


#!/usr/bin/env python3
# @generated AUTOGENERATED file. Do not Change!

from dataclasses import dataclass, field as _field
from functools import partial
from ...config import custom_scalars, datetime
from numbers import Number
from typing import Any, AsyncGenerator, Dict, List, Generator, Optional

from dataclasses_json import DataClassJsonMixin, config

from gql_client.runtime.enum_utils import enum_field_metadata
from ..enum.work_order_priority import WorkOrderPriority
from ..enum.work_order_status import WorkOrderStatus

from ..input.check_list_category_input import CheckListCategoryInput
from ..input.check_list_item_input import CheckListItemInput
from ..input.property_input import PropertyInput


@dataclass(frozen=True)
class AddWorkOrderInput(DataClassJsonMixin):
    name: str
    workOrderTypeId: str
    properties: List[PropertyInput]
    checkList: List[CheckListItemInput]
    checkListCategories: List[CheckListCategoryInput]
    description: Optional[str] = None
    locationId: Optional[str] = None
    projectId: Optional[str] = None
    ownerId: Optional[str] = None
    assigneeId: Optional[str] = None
    index: Optional[int] = None
    organizationFk: Optional[str] = None
    status: Optional[WorkOrderStatus] = None
    priority: Optional[WorkOrderPriority] = None
    duration: Optional[Number] = None
    dueDate: Optional[datetime] = None



#!/usr/bin/env python3
# Copyright (c) 2004-present Facebook All rights reserved.
# Use of this source code is governed by a BSD-style
# license that can be found in the LICENSE file.

from typing import Iterator, List, Mapping, Optional

from psym._utils import get_graphql_property_type_inputs
from psym.client import SymphonyClient
from psym.common.cache import WORK_ORDER_TYPES
from psym.common.data_class import PropertyDefinition, PropertyValue, WorkOrderType
from psym.common.data_enum import Entity
from psym.common.data_format import (
    format_to_property_type_inputs,
    format_to_work_order_type,
)
from psym.exceptions import EntityNotFoundError

from ..graphql.input.add_work_order_type_input import AddWorkOrderTypeInput
from ..graphql.input.edit_work_order_type_input import EditWorkOrderTypeInput
from ..graphql.mutation.add_work_order_type import AddWorkOrderTypeMutation
from ..graphql.mutation.edit_work_order_type import EditWorkOrderTypeMutation
from ..graphql.mutation.remove_work_order_type import RemoveWorkOrderTypeMutation
from ..graphql.query.work_order_type_details import WorkOrderTypeDetailsQuery
from ..graphql.query.work_order_types import WorkOrderTypesQuery


def _populate_work_order_types(client: SymphonyClient) -> None:
    edges = WorkOrderTypesQuery.execute(client).edges

    for edge in edges:
        node = edge.node
        if node:
            WORK_ORDER_TYPES[node.name] = format_to_work_order_type(
                work_order_type_fragment=node
            )


def add_work_order_type(
    client: SymphonyClient,
    name: str,
    description: Optional[str] = None,
    properties: List[PropertyDefinition] = None,
) -> WorkOrderType:
    """This function creates WorkOrderType.

    :param name: Work order type name
    :type name: str
    :param description: Work order type description
    :type description: str, optional
    :param properties: List of property definitions
    :type properties: List[ :class:`~psym.common.data_class.PropertyDefinition` ]

    :return: Work order type
    :rtype: :class:`~psym.common.data_class.WorkOrderType`

    **Example**

    .. code-block:: python

        client.add_work_order_type(
            name="Work order type",
            description="Work order type description",
            properties=[
                PropertyDefinition(
                    property_name="work order type property",
                    property_kind=PropertyKind.string,
                    default_raw_value="string value",
                    is_fixed=False,
                )
            ],
        )
    """
    property_type_inputs = []
    if properties is not None:
        property_type_inputs = format_to_property_type_inputs(data=properties)
    result = AddWorkOrderTypeMutation.execute(
        client,
        AddWorkOrderTypeInput(
            name=name,
            description=description,
            properties=property_type_inputs,
            checkListCategories=[],
            assigneeCanCompleteWorkOrder=True,
        ),
    )
    added = format_to_work_order_type(work_order_type_fragment=result)
    WORK_ORDER_TYPES[added.name] = added
    return added


def get_work_order_types(client: SymphonyClient) -> Iterator[WorkOrderType]:
    """Get the iterator of work order types

    :raises:
        FailedOperationException: Internal symphony error

    :return: WorkOrderType Iterator
    :rtype: Iterator[ :class:`~psym.common.data_class.WorkOrderType` ]

    **Example**

    .. code-block:: python

        work_order_types = client.get_work_order_types()
        for work_order_type in work_order_types:
            print(work_order_type.name, work_order_type.description)
    """
    result = WorkOrderTypesQuery.execute(client)
    if result is None:
        return
    for edge in result.edges:
        node = edge.node
        if node is not None:
            yield format_to_work_order_type(work_order_type_fragment=node)


def get_work_order_type_by_id(client: SymphonyClient, id: str) -> WorkOrderType:
    """This function gets existing WorkOrderType by its ID.

    :param id: Work order type ID
    :type id: str

    :raises:
        * FailedOperationException: Internal symphony error
        * :class:`~psym.exceptions.EntityNotFoundError`: Work order type does not exist

    :return: Work order type
    :rtype: :class:`~psym.common.data_class.WorkOrderType`

    **Example**

    .. code-block:: python

        client.get_work_order_type_by_id(id="12345678")
    """
    result = WorkOrderTypeDetailsQuery.execute(client, id=id)

    if result is None:
        raise EntityNotFoundError(entity=Entity.WorkOrderType, entity_id=id)

    return format_to_work_order_type(work_order_type_fragment=result)


def get_work_order_type_by_name(client: SymphonyClient, name: str) -> WorkOrderType:
    """This function gets existing WorkOrderType by its name.

    :param name: Work order type name
    :type name: str

    :raises:
        * FailedOperationException: Internal symphony error
        * :class:`~psym.exceptions.EntityNotFoundError`: Work order type does not exist

    :return: Work order type
    :rtype: :class:`~psym.common.data_class.WorkOrderType`

    **Example**

    .. code-block:: python

        client.get_work_order_type_by_name(name="WorkOrderType Name")
    """

    work_order_types = get_work_order_types(client=client)
    for work_order_type in work_order_types:
        if work_order_type.name == name:
            return work_order_type
    raise EntityNotFoundError(entity=Entity.WorkOrderType, entity_name=name)


def add_property_types_to_work_order_type(
    client: SymphonyClient,
    work_order_type_id: str,
    new_properties: List[PropertyDefinition],
) -> WorkOrderType:
    """This function adds new property types to existing work order type.

    :param work_order_type_id: Existing work order type ID
    :type work_order_type_id: str
    :param new_properties: List of property definitions
    :type new_properties: List[ :class:`~psym.common.data_class.PropertyDefinition` ]

    :raises:
        FailedOperationException: Internal symphony error

    :return: WorkOrderType object
    :rtype: :class:`~psym.common.data_class.WorkOrderType`

    **Example**

    .. code-block:: python

        work_order_type = client.add_property_types_to_work_order_type(
            work_order_type_id="12345678",
            new_properties=[
                PropertyDefinition(
                    property_name="Contact",
                    property_kind=PropertyKind.string,
                    default_raw_value=None,
                    is_fixed=True
                )
            ],
        )
    """
    work_order_type = get_work_order_type_by_id(client=client, id=work_order_type_id)
    new_property_type_inputs = format_to_property_type_inputs(data=new_properties)
    result = EditWorkOrderTypeMutation.execute(
        client,
        EditWorkOrderTypeInput(
            id=work_order_type.id,
            name=work_order_type.name,
            description=work_order_type.description,
            properties=new_property_type_inputs,
            checkListCategories=[],
        ),
    )
    edited = format_to_work_order_type(work_order_type_fragment=result)
    WORK_ORDER_TYPES.pop(work_order_type.name)
    WORK_ORDER_TYPES[edited.name] = edited
    return edited


def edit_work_order_type(
    client: SymphonyClient,
    work_order_type_id: str,
    new_name: Optional[str] = None,
    new_description: Optional[str] = None,
    new_properties_defaults: Optional[Mapping[str, PropertyValue]] = None,
) -> WorkOrderType:
    """This function edits existing WorkOrderType.

    :param work_order_type_id: Existing work order type ID
    :type work_order_type_id: str
    :param new_name: Work order type new name
    :type new_name: str, optional
    :param new_description: Work order type new description
    :type new_description: str, optional
    :param new_properties_defaults: Mapping of property name to property default value

        * str - property name
        * PropertyValue - new default value of the same type for this property

    :type new_properties_defaults: Mapping[str, PropertyValue], optional

    :raises:
        * FailedOperationException: Internal symphony error
        * :class:`~psym.exceptions.EntityNotFoundError`: Work order type does not exist

    :return: Work order type
    :rtype: :class:`~psym.common.data_class.WorkOrderType`

    **Example**

    .. code-block:: python

        edited_work_order_type = client.edit_work_order_type(
            work_order_type_id="12345678,
            new_name="New name",
            new_description="New description",
        )
    """
    work_order_type = get_work_order_type_by_id(client=client, id=work_order_type_id)
    new_name = work_order_type.name if new_name is None else new_name
    new_description = (
        work_order_type.description if new_description is None else new_description
    )

    new_property_type_inputs = []
    if new_properties_defaults:
        property_types = work_order_type.property_types
        new_property_type_inputs = get_graphql_property_type_inputs(
            property_types, new_properties_defaults
        )
    result = EditWorkOrderTypeMutation.execute(
        client,
        EditWorkOrderTypeInput(
            id=work_order_type.id,
            name=new_name,
            description=new_description,
            properties=new_property_type_inputs,
            checkListCategories=[],
        ),
    )
    edited = format_to_work_order_type(work_order_type_fragment=result)
    WORK_ORDER_TYPES.pop(work_order_type.name)
    WORK_ORDER_TYPES[edited.name] = edited
    return edited


def delete_work_order_type(client: SymphonyClient, work_order_type_id: str) -> None:
    """This function deletes WorkOrderType.

    :param work_order_type_id: Work order type ID
    :type work_order_type_id: str

    :raises:
        * FailedOperationException: Internal symphony error
        * :class:`~psym.exceptions.EntityNotFoundError`: Work order type does not exist

    **Example**

    .. code-block:: python

        client.delete_work_order_type("12345678")
    """
    work_order_type = get_work_order_type_by_id(client=client, id=work_order_type_id)
    if work_order_type is None:
        raise EntityNotFoundError(
            entity=Entity.WorkOrderType, entity_id=work_order_type_id
        )
    RemoveWorkOrderTypeMutation.execute(client, id=work_order_type_id)
    del WORK_ORDER_TYPES[work_order_type.name]



#!/usr/bin/env python3
# Copyright (c) 2004-present Facebook All rights reserved.
# Use of this source code is governed by a BSD-style
# license that can be found in the LICENSE file.

from typing import List

from psym.client import SymphonyClient
from psym.common.constant import GET_FEATURES_URL, SET_FEATURE_URL

from ..exceptions import assert_ok


def get_enabled_features(client: SymphonyClient) -> List[str]:
    """Returns list of the enabled features that are accessible publicly

    :raises:
        AssertionError: Server error

    :return: Enabled features list
    :rtype: List[str]

    **Example**

    .. code-block:: python

        features = client.get_enabled_features()
    """
    resp = client.get(GET_FEATURES_URL)
    assert_ok(resp)
    return list(map(str, resp.json()["features"]))


def set_feature(client: SymphonyClient, feature_id: str, enabled: bool) -> None:
    """Enable or disable given feature if the feature is publicly accessible

    :param feature_id: The feature identifier to set
    :type feature_id: str
    :param enabled: Enabled or disabled flag
    :type enabled: bool

    :raises:
        AssertionError: Server error

    :return: None

    **Example**

    .. code-block:: python

        features = client.get_enabled_features()
        client.set_feature(feature[0], False)
    """
    resp = client.post(SET_FEATURE_URL.format(feature_id), {"enabled": enabled})
    assert_ok(resp)



#!/usr/bin/env python3
# Copyright (c) 2004-present Facebook All rights reserved.
# Use of this source code is governed by a BSD-style
# license that can be found in the LICENSE file.


from psym.client import SymphonyClient
from psym.common.data_class import Vendor

from ..graphql.input.edit_vendor_input import EditVendorInput
from ..graphql.input.add_vendor_input import AddVendorInput
from ..graphql.mutation.add_vendor import addVendor
from ..graphql.mutation.edit_vendor import editVendor
from ..graphql.mutation.remove_vendor import removeVendor
from ..graphql.query.vendors import vendors
from psym.common.constant import PAGINATION_STEP
from typing import Any, Dict, Iterator, List, Optional




def add_vendor(
    client: SymphonyClient, name: str
) -> Vendor:
   
    vendor_input = AddVendorInput(name=name)
    result = addVendor.execute(client, input=vendor_input)
    return Vendor(name=result.name, id=result.id)

def edit_vendor(
    client: SymphonyClient,
    vendor: Vendor,
    new_name: Optional[str] = None,
) -> None:
    params: Dict[str, Any] = {}
    if new_name is not None:
        params.update({"_name_": new_name})
    if new_name is not None:
        editVendor.execute(client, input=EditVendorInput(id=vendor.id, name=new_name))


def get_vendors(client: SymphonyClient) -> Iterator[Vendor]:

    vendors_ = vendors.execute(client, first=PAGINATION_STEP)
    edges = vendors_.edges if vendors_ else []
    while vendors_ is not None and vendors_.pageInfo.hasNextPage:
        vendors_ = vendors.execute(
            client, after=vendors_.pageInfo.endCursor, first=PAGINATION_STEP
        )
        if vendors_ is not None:
            edges.extend(vendors_.edges)

    for edge in edges:
        node = edge.node
        if node is not None:
            yield Vendor(
                id=node.id,
                name=node.name,
            )


def remove_vendor(client: SymphonyClient, id: str) -> None:
    removeVendor.execute(client, id=id)


#!/usr/bin/env python3
# Copyright (c) 2004-present Facebook All rights reserved.
# Use of this source code is governed by a BSD-style
# license that can be found in the LICENSE file.

from typing import Iterator, List, Mapping, Optional

from psym.client import SymphonyClient
from psym.common.cache import SERVICE_TYPES
from psym.common.data_class import (
    PropertyDefinition,
    PropertyValue,
    ServiceEndpointDefinition,
    ServiceType,
)
from psym.common.data_enum import Entity
from psym.common.data_format import (
    format_to_property_type_inputs,
    format_to_service_type,
)

from .._utils import get_graphql_property_type_inputs
from ..exceptions import EntityNotFoundError
from ..graphql.input.service_type_create_data import ServiceTypeCreateData
from ..graphql.input.service_type_edit_data import (
    ServiceEndpointDefinitionInput,
    ServiceTypeEditData,
)
from ..graphql.mutation.add_service_type import AddServiceTypeMutation
from ..graphql.mutation.edit_service_type import EditServiceTypeMutation
from ..graphql.mutation.remove_service import RemoveServiceMutation
from ..graphql.mutation.remove_service_type import RemoveServiceTypeMutation
from ..graphql.query.service_type_services import ServiceTypeServicesQuery
from ..graphql.query.service_types import ServiceTypesQuery


def _populate_service_types(client: SymphonyClient) -> None:
    service_types = ServiceTypesQuery.execute(client)
    if not service_types:
        return
    edges = service_types.edges
    for edge in edges:
        node = edge.node
        if node is not None:
            SERVICE_TYPES[node.name] = format_to_service_type(
                service_type_fragment=node
            )


def add_service_type(
    client: SymphonyClient,
    name: str,
    has_customer: bool,
    properties: Optional[List[PropertyDefinition]],
    endpoint_definitions: Optional[List[ServiceEndpointDefinition]],
) -> ServiceType:
    """This function creates new service type.

    :param name: Service type name
    :type name: str
    :param has_customer: Flag for customer existance
    :type has_customer: bool
    :param properties: Property definitions list
    :type properties: List[ :class:`~psym.common.data_class.PropertyDefinition` ], optional
    :param endpoint_definitions: Service endpoint definitions list
    :type endpoint_definitions: List[ :class:`~psym.common.data_class.ServiceEndpointDefinition` ], optional

    :raises:
        FailedOperationException: Internal symphony error

    :return: ServiceType object
    :rtype: :class:`~psym.common.data_class.ServiceType`

    **Example**

    .. code-block:: python

        service_type = client.add_service_type(
            client=self.client,
            name="Internet Access",
            has_customer=True,
            properties=[
                PropertyDefinition(
                    property_name="Service Package",
                    property_kind=PropertyKind.string,
                    default_raw_value="Public 5G",
                    is_fixed=False,
                ),
                PropertyDefinition(
                    property_name="Address Family",
                    property_kind=PropertyKind.string,
                    default_raw_value=None,
                    is_fixed=False,
                ),
            ],
        )
    """

    formated_property_types = None
    if properties is not None:
        formated_property_types = format_to_property_type_inputs(data=properties)
    definition_inputs = []
    if endpoint_definitions:
        for endpoint in endpoint_definitions:
            definition_inputs.append(
                ServiceEndpointDefinitionInput(
                    name=endpoint.name,
                    role=endpoint.role,
                    index=endpoint.endpoint_definition_index,
                    equipmentTypeID=endpoint.equipment_type_id,
                )
            )
    result = AddServiceTypeMutation.execute(
        client,
        data=ServiceTypeCreateData(
            name=name,
            hasCustomer=has_customer,
            properties=formated_property_types,
            endpoints=definition_inputs,
        ),
    )
    service_type = format_to_service_type(service_type_fragment=result)
    SERVICE_TYPES[name] = service_type
    return service_type


def get_service_types(client: SymphonyClient) -> Iterator[ServiceType]:
    """Get the iterator of service types

    :raises:
        FailedOperationException: Internal symphony error

    :return: ServiceType Iterator
    :rtype: Iterator[ :class:`~psym.common.data_class.ServiceType` ]

    **Example**

    .. code-block:: python

        service_types = client.get_service_types()
        for service_type in service_types:
            print(service_type.name, service_type.description)
    """
    result = ServiceTypesQuery.execute(client)
    if result is None:
        return
    for edge in result.edges:
        node = edge.node
        if node is not None:
            yield format_to_service_type(service_type_fragment=node)


def get_service_type(client: SymphonyClient, service_type_id: str) -> ServiceType:
    """Get service type by ID.

    :param service_type_id: Service type ID
    :type service_type_id: str

    :raises:
        :class:`~psym.exceptions.EntityNotFoundError`: Service type with id=`service_type_id` does not found

    :return: ServiceType object
    :rtype: :class:`~psym.common.data_class.ServiceType`

    **Example**

    .. code-block:: python

        service_type = client.get_service_type(
            service_type_id="12345",
        )
    """
    for _, service_type in SERVICE_TYPES.items():
        if service_type.id == service_type_id:
            return service_type

    raise EntityNotFoundError(entity=Entity.ServiceType, entity_id=service_type_id)


def add_property_types_to_service_type(
    client: SymphonyClient,
    service_type_id: str,
    new_properties: List[PropertyDefinition],
) -> ServiceType:
    """This function adds new property types to existing service type.

    :param service_type_id: Existing service type ID
    :type service_type_id: str
    :param new_properties: List of property definitions
    :type new_properties: List[ :class:`~psym.common.data_class.PropertyDefinition` ]

    :raises:
        FailedOperationException: Internal symphony error

    :return: LocationType object
    :rtype: :class:`~psym.common.data_class.LocationType`

    **Example**

    .. code-block:: python

        service_type = client.add_property_types_to_service_type(
            service_type_id="12345678",
            new_properties=[
                PropertyDefinition(
                    property_name="Contact",
                    property_kind=PropertyKind.string,
                    default_raw_value=None,
                    is_fixed=True
                )
            ],
        )
    """
    service_type = get_service_type(client=client, service_type_id=service_type_id)
    new_property_type_inputs = format_to_property_type_inputs(data=new_properties)
    result = EditServiceTypeMutation.execute(
        client,
        ServiceTypeEditData(
            id=service_type.id,
            name=service_type.name,
            hasCustomer=service_type.has_customer,
            properties=new_property_type_inputs,
            endpoints=[],
        ),
    )
    edited = format_to_service_type(service_type_fragment=result)
    SERVICE_TYPES.pop(service_type.name)
    SERVICE_TYPES[edited.name] = edited
    return edited


def edit_service_type(
    client: SymphonyClient,
    service_type: ServiceType,
    new_name: Optional[str] = None,
    new_has_customer: Optional[bool] = None,
    new_properties: Optional[Mapping[str, PropertyValue]] = None,
    new_endpoints: Optional[List[ServiceEndpointDefinition]] = None,
) -> ServiceType:
    """Edit existing service type by ID.

    :param service_type: ServiceType object
    :type service_type: :class:`~psym.common.data_class.ServiceType`
    :param new_name: Service type name
    :type new_name: str, optional
    :param new_has_customer: Flag for customer existance
    :type new_has_customer: bool, optional
    :param new_properties: Property definitions list
    :type new_properties: List[ :class:`~psym.common.data_class.PropertyDefinition` ], optional
    :param new_endpoints: Service endpont definitions list
    :type new_endpoints: List[ :class:`~psym.common.data_class.ServiceEndpointDefinition` ], optional

    :raises:
        :class:`~psym.exceptions.EntityNotFoundError`: Service type with id=`service_type_id` does not found

    :return: ServiceType object
    :rtype: :class:`~psym.common.data_class.ServiceType`

    **Example**

    .. code-block:: python

        service_type = client.edit_service_type(
            service_type=service_type,
            new_name="new service type name",
            new_properties={"existing property name": "new value"},
            new_endpoints=[
                ServiceEndpointDefinition(
                    id="endpoint_def_id",
                    name="endpoint_def_name",
                    role="endpoint_def_role",
                    index=1,
                ),
            ],
        )
    """
    new_name = service_type.name if new_name is None else new_name
    new_has_customer = (
        service_type.has_customer if new_has_customer is None else new_has_customer
    )

    new_property_type_inputs = []
    if new_properties:
        property_types = SERVICE_TYPES[service_type.name].property_types
        new_property_type_inputs = get_graphql_property_type_inputs(
            property_types, new_properties
        )

    new_endpoints_definition_inputs = []
    if new_endpoints:
        for endpoint in new_endpoints:
            new_endpoints_definition_inputs.append(
                ServiceEndpointDefinitionInput(
                    name=endpoint.name,
                    role=endpoint.role,
                    index=endpoint.endpoint_definition_index,
                    equipmentTypeID=endpoint.equipment_type_id,
                )
            )

    result = EditServiceTypeMutation.execute(
        client,
        ServiceTypeEditData(
            id=service_type.id,
            name=new_name,
            hasCustomer=new_has_customer,
            properties=new_property_type_inputs,
            endpoints=new_endpoints_definition_inputs,
        ),
    )
    service_type = format_to_service_type(service_type_fragment=result)
    SERVICE_TYPES[service_type.name] = service_type
    return service_type


def delete_service_type(client: SymphonyClient, service_type: ServiceType) -> None:
    """This function deletes an service type.
    It gets the requested service type ID

    :param service_type: ServiceType object
    :type service_type: :class:`~psym.common.data_class.ServiceType`

    :rtype: None

    **Example**

    .. code-block:: python

        client.delete_service_type(service_type_id=service_type.id)
    """
    RemoveServiceTypeMutation.execute(client, id=service_type.id)
    del SERVICE_TYPES[service_type.name]


def delete_service_type_with_services(
    client: SymphonyClient, service_type: ServiceType
) -> None:
    """Delete service type with existing services.

    :param service_type: ServiceType object
    :type service_type: :class:`~psym.common.data_class.ServiceType`

    :raises:
        :class:`~psym.exceptions.EntityNotFoundError`: Service type does not exist

    :rtype: None

    **Example**

    .. code-block:: python

        client.delete_service_type_with_services(service_type=service_type)
    """
    service_type_with_services = ServiceTypeServicesQuery.execute(
        client, id=service_type.id
    )
    if not service_type_with_services:
        raise EntityNotFoundError(entity=Entity.ServiceType, entity_id=service_type.id)
    services = service_type_with_services.services
    for service in services:
        RemoveServiceMutation.execute(client, id=service.id)
    RemoveServiceTypeMutation.execute(client, id=service_type.id)
    del SERVICE_TYPES[service_type.name]



#!/usr/bin/env python3
# Copyright (c) 2004-present Facebook All rights reserved.
# Use of this source code is governed by a BSD-style
# license that can be found in the LICENSE file.


from psym.client import SymphonyClient
from psym.common.data_class import  NetworkType, formula, Kpi, tech

from ..graphql.input.edit_formula_input import EditFormulaInput
from ..graphql.input.add_formula_input import AddFormulaInput
from ..graphql.mutation.add_formula import addFormula
from ..graphql.mutation.edit_formula import editFormula
from ..graphql.mutation.remove_formula import removeFormula
from ..graphql.query.formulas import formulas
from psym.common.constant import PAGINATION_STEP
from typing import Any, Dict, Iterator, List, Optional




def add_formula(
    client: SymphonyClient, textFormula: str, status: bool,  tech: str, networkType: str,  kpi: str
) -> formula:
   
    formula_input = AddFormulaInput(
    textFormula=textFormula, 
    status=status, 
    techFk= tech,
    networkTypeFk= networkType,
    kpiFk= kpi
   
   )
    result = addFormula.execute(client, input=formula_input)
    return formula(textFormula=result.textFormula, 
    id=result.id,  
    status=result.status, 
    techFk=result.techFk,
    networkTypeFk=result.networkTypeFk,
    kpiFk=result.kpiFk
)

def edit_formula(
    client: SymphonyClient,
    formula: formula,
    new_name: Optional[str] = None,
    status: bool = None,
    tech: tech = None,
    networkType: NetworkType = None,
    kpi: Kpi = None
) -> None:
    params: Dict[str, Any] = {}
    if new_name is not None:
        params.update({"_name_": new_name})
    if new_name is not None:
        editFormula.execute(client, input=EditFormulaInput(
        id=formula.id, 
        textFormula=new_name,
        status= status,
        networkTypeFk=networkType,
        kpiFk=kpi,
        techFk=tech
        ))


def get_formulas(client: SymphonyClient) -> Iterator[Kpi]:

    formulas_ = formulas.execute(client, first=PAGINATION_STEP)
    edges = formulas_.edges if formulas_ else []
    while formulas_ is not None and formulas_.pageInfo.hasNextPage:
        formulas_ = formulas.execute(
            client, after=formulas_.pageInfo.endCursor, first=PAGINATION_STEP
        )
        if formulas_ is not None:
            edges.extend(formulas_.edges)

    for edge in edges:
        node = edge.node
        if node is not None:
            yield formula(
                id=node.id,
                textFormula=node.textFormula,
                status=node.status,
                networkTypeFk=node.networkTypeFk,
                kpiFk=node.kpiFk,
                techFk=node.techFk

            )


def remove_formula(client: SymphonyClient, id: str) -> None:
    removeFormula.execute(client, id=id)











#!/usr/bin/env python3
# Copyright (c) 2004-present Facebook All rights reserved.
# Use of this source code is governed by a BSD-style
# license that can be found in the LICENSE file.


from psym.client import SymphonyClient
from psym.common.data_class import recommendations

from ..graphql.input.edit_recommendations_input import EditRecommendationsInput
from ..graphql.input.add_recommendations_input import AddRecommendationsInput
from ..graphql.mutation.add_recommendations import addRecommendations
from ..graphql.mutation.edit_recommendations import editRecommendations
#from ..graphql.mutation.remove_recommendations import removeRecommendations
#from ..graphql.query.recommendationss import recommendationss
from psym.common.constant import PAGINATION_STEP
from typing import Any, Dict, Iterator, List, Optional




def add_recommendations(
    client: SymphonyClient, externalID: str,
    resource: str,
    alarmType: str,
    shortDescription: str,
    LongDescription: str,
    command: str,
    runbook: str,
    priority: str,
    status: bool,
    used: int,
    vendor: str,
    RecomendationSources: str,
    RecomendationsCategory: str,
    userCreated: int,
    userApproved: int,
) -> recommendations:
    recommendations_input = AddRecommendationsInput(
    externalID=externalID,
    resource=resource,
    alarmType=alarmType,
    shortDescription=shortDescription,
    longDescription=LongDescription,
    priority=priority,
    status=status,
    recommendationsSources=RecomendationSources,
    recommendationsCategory=RecomendationsCategory,
    userCreate=userCreated,
    vendor=vendor,
    command=command,
    runbook=runbook,
    used=used,
    userApprobed=userApproved,
    )
    result = addRecommendations.execute(client, input=recommendations_input)
    return recommendations(
    id=result.id,
    externalID=result.externalID,
    resource=result.resource,
    alarmType=result.alarmType,
    shortDescription=result.shortDescription,
    LongDescription=result.longDescription,
    command=result.command,
    runbook=result.runbook,
    priority=result.priority,
    status=result.status,
    used=result.used,
    vendor=result.vendor,
    RecomendationSources=result.recommendationsSources,
    RecomendationsCategory=result.recommendationsCategory,
    userCreated=result.userCreate,
    userApproved=result.userApprobed
    )

def edit_recommendations(
    client: SymphonyClient,
    recommendations:recommendations,
    new_externalID:str=None,
    resource:str=None,
    alarmType:str=None,
    shortDescription:str=None,
    LongDescription:str=None,
    command:str=None,
    runbook:str=None,
    priority:int=None,
    status:bool=None,
    used:int=None,
    vendor:str=None,
    RecomendationSources:str=None,
    RecomendationsCategory:str=None,
    userApproved:str=None
) ->None:
    params: Dict[str, Any] = {}
    if new_externalID is not None:
        params.update({"_name_": new_externalID})
    if new_externalID is not None:
        editRecommendations.execute(client, input=EditRecommendationsInput(
            id=recommendations.id,
            externalID=new_externalID,
            resource=resource,
            alarmType=alarmType,
            shortDescription=shortDescription,
            longDescription=LongDescription,
            priority=priority,
            status=status,
            recommendationsSources=RecomendationSources,
            recommendationsCategory=RecomendationsCategory,
            vendor=vendor,
            command=command,
            runbook=runbook,
            used=used,
            userApprobed=userApproved))